#!/usr/bin/perl -w
#< Boilerplate
#
# The Aranea question answering system
# Copyright (C) 2002-2005, Jimmy Lin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, please visit
# http://www.gnu.org/copyleft/gpl.html
#
# $Header: /fs/clip-qa/.cvsroot//Aranea/pm/Aranea/Modules/ConvertToTREC.pm,v 1.15 2005/06/10 16:17:16 jimmylin Exp $
#
#>
#< POD
###############################################################################

=head1 NAME

B<C<Aranea::Modules::ConvertToTREC>> - Aranea module for displaying
results in the TREC8/9/10 format

=head1 SYNOPSIS

This Aranea modules is meant to be used in conjunction with the
L<C<Aranea::Shell>|Aranea::Shell>.

=head1 DESCRIPTION

This Areana module converts the Aranea XML object into the TREC8/9/10
answer output format:

  QNO Q0 DOCID RANK SCORE SYSTEM ANSWER

C<QNO> is the question number; C<Q0> is just some identifier
(meaningless); C<DOCID> is the id of the supporting document; C<RANK>
is the rank of the answer; C<SCORE> is the internal score of the
answer (does not affect judging); C<SYSTEM> is the name of the system;
C<ANSWER> is the actual answer itself.  Here is an example:

  Question 233: Who made the first airplane?
  233 Q0 Doc 1 1959.41814325367 aranea Orville Wright
  233 Q0 Doc 2 1815.34553754545 aranea Orville and Wilbur Wright
  233 Q0 Doc 3 1681.04468251363 aranea Wright Brothers
  233 Q0 Doc 4 748.966302734287 aranea Wilbur and Orville

Note that starting TREC 2002, the output format has changed.

=cut

###############################################################################
#>
#< Header
package Aranea::Modules::ConvertToTREC;

use strict;
use warnings;

use IO::Handle;

use Aranea::XML::Aranea;

#>

#< STDIN handler
unless ( caller() ) {
    my $stdin = new_from_fd IO::Handle(fileno(STDIN),"r");
    my $Aranea = Aranea::XML::Aranea->new($stdin);

    $Aranea = doModule($Aranea);

    $Aranea->write_xml();
}
#>

#< sub doModule
sub doModule {
    my $Aranea = shift;

    $Aranea->insert_pipeline_tag('$Id: ConvertToTREC.pm,v 1.15 2005/06/10 16:17:16 jimmylin Exp $ ');

    my $qid = $Aranea->query()->id();

    if ( $Aranea->candidate_list()->entries_count() == -1 ) {
	print "$qid Q0 Doc 1 1 aranea NIL\n";
    } else {
	my $entries = $Aranea->candidate_list()->entries();

	@$entries = sort { $b->score() <=> $a->score() } @$entries;

	my $i = 0;
	for my $entry (@$entries) {
	    $i++;
	    last if $i > 20;
	    my $candidate = $entry->candidate();
	    my $score = $entry->score();
	    
	    my $supportdocs = $entry->support_docs();
	    
	    my $trec = '';
	    foreach my $support ( @$supportdocs ) {
		if ( $support !~ /^http:/ and $support !~ /\// ) {
		    $trec = $support;
		    last;
		}
	    }
	    
	    $trec = 'Doc' if $trec eq '';
	    print "$qid Q0 $trec $i $score aranea $candidate\n";
	}
    }

    return $Aranea;
}
#>

1;
