#!/usr/bin/perl -w
#< Boilerplate
#
# The Aranea question answering system
# Copyright (C) 2002-2005, Jimmy Lin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, please visit
# http://www.gnu.org/copyleft/gpl.html
#
# $Header: /fs/clip-qa/.cvsroot//Aranea/pm/Aranea/Modules/PrintTopAnswer.pm,v 1.4 2005/06/10 16:17:16 jimmylin Exp $
#
#>
#< POD
###############################################################################

=head1 NAME

B<C<Aranea::Modules::PrintTopAnswer>> - Aranea module for printing the
top answer in the latest TREC format

=head1 SYNOPSIS

This Aranea modules is meant to be used in conjunction with the
L<C<Aranea::Shell>|Aranea::Shell>.

=head1 DESCRIPTION

This Aranea module prints only the top answer in the latest TREC
format.

=cut

###############################################################################
#>
#< Header
package Aranea::Modules::PrintTopAnswer;

use strict;
use warnings;

use IO::Handle;

use Aranea::XML::Aranea;

#>

#< STDIN handler
unless ( caller() ) {
    my $stdin = new_from_fd IO::Handle(fileno(STDIN),"r");
    my $Aranea = Aranea::XML::Aranea->new($stdin);

    $Aranea = doModule($Aranea);

    $Aranea->write_xml();
}
#>

#< sub doModule
sub doModule {
    my $Aranea = shift;

    $Aranea->insert_pipeline_tag('$Id: PrintTopAnswer.pm,v 1.4 2005/06/10 16:17:16 jimmylin Exp $ ');

    my $runtag = "aranea-answer";
    my $qid = $Aranea->query()->id();

    if ( $Aranea->candidate_list()->entries_count() == -1 ) {
	print "$qid $runtag NIL\n";
    } else {
	my $entries = $Aranea->candidate_list()->entries();

	@$entries = sort { $b->score() <=> $a->score() } @$entries;

	my $entry = $entries->[0];

	my $candidate = $entry->candidate();
	my $score = $entry->score();
	my $supportdocs = $entry->support_docs();

	my $trec = '';
	foreach my $support ( @$supportdocs ) {
	    if ( $support !~ /^http:/ and $support !~ /\// ) {
		$trec = $support;
		last;
	    }
	}

	print "$qid $runtag $trec $candidate\n";
    }

    return $Aranea;
}
#>

1;
