#!/usr/bin/perl -w
#< Boilerplate
#
# The Aranea question answering system
# Copyright (C) 2002-2005, Jimmy Lin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, please visit
# http://www.gnu.org/copyleft/gpl.html
#
# $Header: /fs/clip-qa/.cvsroot//Aranea/pm/Aranea/Patterns/Locations.pm,v 1.9 2005/06/08 02:51:43 jimmylin Exp $
#
#>
#< Header
package Aranea::Patterns::Locations;

use strict;
use warnings;

use Exporter;

our @ISA = qw(Exporter);
our @EXPORT = qw();
our @EXPORT_OK = qw(exactify_location %ADJ_TO_LOCATION $ADJ_TO_LOCATION_keys $COUNTRY $POSTAL_CODE $STATE %STATE_TO_POSTAL_CODE %POSTAL_CODE_TO_STATE %STATE_TO_ABBREV %ABBREV_TO_STATE $CANADIAN_PROVINCE $COLLEGE);

#>

#< hash: ADJ_TO_LOCATION
our %ADJ_TO_LOCATION = (
  # continents/regions (note: Australia is a country also)
  'South American' => [ 'South America' ],
  'North American' => [ 'North America' ],
  'Central American' => [ 'Central America' ],
  'Asian' => [ 'Asia' ],
  'African' => [ 'Africa' ],
  'European' => [ 'Europe' ],

  # common regions
  'Alaskan' => [ 'Alaska' ],
  'Hawaiian' => [ 'Hawaii' ],
  'Scottish' => [ 'Scotland' ],

  # countries
  'Afghan' => [ 'Afghanistan' ],
  'Albanian' => [ 'Albania' ],
  'Algerian' => [ 'Algeria' ],
  'American Samoan' => [ 'American Samoa' ],
  'Andorran' => [ 'Andorra' ],
  'Angolan' => [ 'Angola' ],
  'Anguillan' => [ 'Anguilla' ],
  'Antiguan' => [ 'Antigua and Barbuda' ],
  'Barbudan' => [ 'Antigua and Barbuda' ],
  'Argentinian' => [ 'Argentina' ],
  'Argentine' => [ 'Argentina' ],
  'Armenian' => [ 'Armenia' ],
  'Aruban' => [ 'Aruba' ],
  'Australian' => [ 'Australia' ],
  'Austrian' => [ 'Austria' ],
  'Azerbaijani' => [ 'Azerbaijan' ],
  'Bahraini' => [ 'Bahrain' ],
  'Barbadian' => [ 'Barbados' ],
  'Belarusian' => [ 'Belarus' ],
  'Belgian' => [ 'Belgium' ],
  'Belizean' => [ 'Belize' ],
  'Beninese' => [ 'Benin' ],
  'Bermudian' => [ 'Bermuda' ],
  'Bhutanese' => [ 'Bhutan' ],
  'Bolivian' => [ 'Bolivia' ],
  'Bosnian' => [ 'Bosnia and Herzegovina' ],
  'Motswana' => [ 'Botswana' ],
  'Batswana' => [ 'Botswana' ],
  'Brazilian' => [ 'Brazil' ],
  'British' => [ 'United Kingdom' ],
  'English' => [ 'United Kingdom' ],
  'British Virgin Islander' => [ 'British Virgin Islands' ],
  'Bruneian' => [ 'Brunei' ],
  'Bulgarian' => [ 'Bulgaria' ],
  'Burkinabe' => [ 'Burkina Faso' ],
  'Burmese' => [ 'Burma' ],
  'Burundi' => [ 'Burundi' ],
  'Cambodian' => [ 'Cambodia' ],
  'Cameroonian' => [ 'Cameroon' ],
  'Canadian' => [ 'Canada' ],
  'Cape Verdean' => [ 'Cape Verde' ],
  'Caymanian' => [ 'Cayman Islands' ],
  'Central African' => [ 'Central African Republic' ],
  'Chadean' => [ 'Chad' ],
  'Chilean' => [ 'Chile' ],
  'Chinese' => [ 'China' ],
  'Cocos Islander' => [ 'Cocos Islands', 'Cocos (Keeling) Islands' ],
  'Colombian' => [ 'Colombia' ],
  'Comoran' => [ 'Comoros' ],
  'Congolese' => [ 'Congo, Republic of the', 'Congo' ],
  'Cook Islander' => [ 'Cook Islands' ],
  'Ivorian' => [ 'Cote d\'Ivoire' ],
  'Costa Rican' => [ 'Costa Rica' ],
  'Croatian' => [ 'Croatia' ],
  'Cuban' => [ 'Cuba' ],
  'Cypriot' => [ 'Cyprus' ],
  'Czech' => [ 'Czech Republic' ],
  'Czechoslovakian' => [ 'Czech Republic' ],
  'Danish' => [ 'Denmark' ],
  'Djiboutian' => [ 'Djibouti' ],
  'Dominican' => [ 'Dominican Republic', 'Dominica' ],
  'East Timorese' => [ 'East Timor' ],
  'Ecuadorian' => [ 'Ecuador' ],
  'Equatorial Guinean' => [ 'Equatorial Guinea' ],
  'Equatorial Guinea' => [ 'Equatorial Guinea' ],
  'Egyptian' => [ 'Egypt' ],
  'Salvadoran' => [ 'El Salvador' ],
  'Eritrean' => [ 'Eritrea' ],
  'Estonian' => [ 'Estonia' ],
  'Ethiopian' => [ 'Ethiopia' ],
  'Faroese' => [ 'Faroe Islands' ],
  'Fijian' => [ 'Fiji' ],
  'Finnish' => [ 'Finland' ],
  'French' => [ 'France' ],
  'French Guianese' => [ 'French Guiana' ],
  'French Polynesian' => [ 'French Polynesia' ],
  'Gabonese' => [ 'Gabon' ],
  'Georgian' => [ 'Georgia' ],
  'Gambian' => [ 'The Gambia' ],
  'German' => [ 'Germany' ],
  'Ghanaian' => [ 'Ghana' ],
  'Greek' => [ 'Greece' ],
  'Greenlandic' => [ 'Greenland' ],
  'Grenadian' => [ 'Grenada' ],
  'Guamanian' => [ 'Guam' ],
  'Guatemalan' => [ 'Guatemala' ],
  'Channel Islander' => [ 'Guernsey' ],
  'Guinean' => [ 'Guinea' ],
  'Guinea-Bissauan' => [ 'Guinea-Bissau' ],
  'Guyanese' => [ 'Guyana' ],
  'Haitian' => [ 'Haiti' ],
  'Dutch' => [ 'Netherlands' ],
  'Honduran' => [ 'Honduras' ],
  'Hungarian' => [ 'Hungary' ],
  'Icelandic' => [ 'Iceland' ],
  'Indian' => [ 'India' ],
  'Indonesian' => [ 'Indonesia' ],
  'Iranian' => [ 'Iran' ],
  'Iraqi' => [ 'Iraq' ],
  'Irish' => [ 'Ireland' ],
  'Israeli' => [ 'Israel' ],
  'Manx' => [ 'Isle of Man' ],
  'Italian' => [ 'Italy' ],
  'Jamaican' => [ 'Jamaica' ],
  'Japanese' => [ 'Japan' ],
  'Jordanian' => [ 'Jordan' ],
  'Kazakstani' => [ 'Kazakhstan' ],
  'Kenyan' => [ 'Kenya' ],
  'Kiribati' => [ 'Kiribati' ],
  'Korean' => [ 'Korea' ],
  'South Korean' => [ 'South Korea' ],
  'Kuwaiti' => [ 'Kuwait' ],
  'Kyrgyz' => [ 'Kyrgyzstan' ],
  'Laotian' => [ 'Laos' ],
  'Lao' => [ 'Laos' ],
  'Latvian' => [ 'Latvia' ],
  'Lebanese' => [ 'Lebanon' ],
  'Basotho' => [ 'Lesotho' ],
  'Liberian' => [ 'Liberia' ],
  'Libyan' => [ 'Libya' ],
  'Lithuanian' => [ 'Lithuania' ],
  'Macedonian' => [ 'Macedonia, The Former Yugoslav Republic of' ],
  'Malagasy' => [ 'Madagascar' ],
  'Malawian' => [ 'Malawi' ],
  'Malaysian' => [ 'Malaysia' ],
  'Maldivian' => [ 'Maldives' ],
  'Malian' => [ 'Mali' ],
  'Maltese' => [ 'Malta' ],
  'Marshallese' => [ 'Marshall Islands' ],
  'Martiniquais' => [ 'Martinique' ],
  'Mauritanian' => [ 'Mauritania' ],
  'Mauritian' => [ 'Mauritius' ],
  'Mahoran' => [ 'Mayotte' ],
  'Mexican' => [ 'Mexico' ],
  'Micronesian' => [ 'Micronesia, Federated States of' ],
  'Kosrae' => [ 'Micronesia, Federated States of' ],
  'Kosraes' => [ 'Micronesia, Federated States of' ],
  'Pohnpeian' => [ 'Micronesia, Federated States of' ],
  'Pohnpeians' => [ 'Micronesia, Federated States of' ],
  'Trukese' => [ 'Micronesia, Federated States of' ],
  'Yapese' => [ 'Micronesia, Federated States of' ],
  'Moldovan' => [ 'Moldova' ],
  'Monacan' => [ 'Monaco' ],
  'Monegasque' => [ 'Monaco' ],
  'Mongolian' => [ 'Mongolia' ],
  'Montserratian' => [ 'Montserrat' ],
  'Moroccan' => [ 'Morocco' ],
  'Mozambican' => [ 'Mozambique' ],
  'Namibian' => [ 'Namibia' ],
  'Nauruan' => [ 'Nauru' ],
  'Nepalese' => [ 'Nepal' ],
  'Nepali' => [ 'Nepal' ],
  'Netherlands Antillean' => [ 'Netherlands Antilles' ],
  'New Caledonian' => [ 'New Caledonia' ],
  'Nicaraguan' => [ 'Nicaragua' ],
  'Nigerien' => [ 'Niger' ],
  'Nigerian' => [ 'Nigeria' ],
  'Niuean' => [ 'Niue' ],
  'Norfolk Islander' => [ 'Norfolk Island' ],
  'North Korean' => [ 'North Korea' ],
  'Norwegian' => [ 'Norway' ],
  'Omani' => [ 'Oman' ],
  'Pakistani' => [ 'Pakistan' ],
  'Palauan' => [ 'Palau' ],
  'Panamanian' => [ 'Panama' ],
  'New Guinean' => [ 'New Guinea' ],
  'Papua New Guinean' => [ 'Papua New Guinea' ],
  'Paraguayan' => [ 'Paraguay' ],
  'Peruvian' => [ 'Peru' ],
  'Philippine' => [ 'Philippines' ],
  'Pitcairn Islander' => [ 'Pitcairn Islands' ],
  'Polish' => [ 'Poland' ],
  'Portuguese' => [ 'Portugal' ],
  'Puerto Rican' => [ 'Puerto Rico' ],
  'Qatari' => [ 'Qatar' ],
  'Reunionese' => [ 'Reunion' ],
  'Romanian' => [ 'Romania' ],
  'Rumanian' => [ 'Romania' ],
  'Russian' => [ 'Russia' ],
  'Rwandan' => [ 'Rwanda' ],
  'Saint Helenian' => [ 'Saint Helena' ],
  'Saint Lucian' => [ 'Saint Lucia' ],
  'Saint Vincentian' => [ 'Saint Vincent and the Grenadines' ],
  'Vincentian' => [ 'Saint Vincent and the Grenadines' ],
  'Sammarinese' => [ 'San Marino' ],
  'Sao Tomean' => [ 'Sao Tome' ],
  'Sao Tomean' => [ 'Sao Tome and Principe' ],
  'Saudi Arabian' => [ 'Saudi Arabia' ],
  'Senegalese' => [ 'Senegal' ],
  'Serbian' => [ 'Yugoslavia' ],
  'Sierra Leonean' => [ 'Sierra Leone' ],
  'Slovak' => [ 'Slovakia' ],
  'Slovenian' => [ 'Slovenia' ],
  'Solomon Islander' => [ 'Solomon Islands' ],
  'Somali' => [ 'Somalia' ],
  'South African' => [ 'South Africa' ],
  'Spanish' => [ 'Spain' ],
  'Sri Lankan' => [ 'Sri Lanka' ],
  'Sudanese' => [ 'Sudan' ],
  'Surinamese' => [ 'Suriname' ],
  'Swazi' => [ 'Swaziland' ],
  'Swedish' => [ 'Sweden' ],
  'Swiss' => [ 'Switzerland' ],
  'Syrian' => [ 'Syria' ],
  'Taiwanese' => [ 'Taiwan' ],
  'Tajik' => [ 'Tajikistan' ],
  'Tanzanian' => [ 'Tanzania' ],
  'Thai' => [ 'Thailand' ],
  'Bahamian' => [ 'The Bahamas' ],
  'Togolese' => [ 'Togo' ],
  'Trinidadian' => [ 'Trinidad and Tobago' ],
  'Tobagonian' => [ 'Trinidad and Tobago' ],
  'Tunisian' => [ 'Tunisia' ],
  'Turkish' => [ 'Turkey' ],
  'Turkmen' => [ 'Turkmenistan' ],
  'Ugandan' => [ 'Uganda' ],
  'Ukrainian' => [ 'Ukraine' ],
  'Ukranian' => [ 'Ukraine' ],
  'Emirian' => [ 'United Arab Emirates' ],
  'American' => [ 'United States' ],
  'Uruguayan' => [ 'Uruguay' ],
  'Uzbek' => [ 'Uzbekistan' ],
  'Ni-Vanuatu' => [ 'Vanuatu' ],
  'Venezuelan' => [ 'Venezuela' ],
  'Vietnamese' => [ 'Vietnam' ],
  'Virgin Islander' => [ 'Virgin Islands' ],
  'Wallisian' => [ 'Wallis and Futuna' ],
  'Futunan' => [ 'Wallis and Futuna' ],
  'Sahrawian' => [ 'Western Sahara' ],
  'Sahraouian' => [ 'Western Sahara' ],
  'Western Samoan' => [ 'Samoa' ],
  'Yemeni' => [ 'Yemen' ],
  'Zairian' => [ 'Congo, Democratic Republic of the' ],
  'Zambia' => [ 'Zambia' ],
  'Zimbabwean' => [ 'Zimbabwe' ],
);

my $ADJ_TO_LOCATION_keys_tmp = "(?:" . (join '|', map { s/ /\\s+/g; $_ } sort keys(%ADJ_TO_LOCATION)) . ")";

our $ADJ_TO_LOCATION_keys = qr{$ADJ_TO_LOCATION_keys_tmp}ox;
#>
#< hash: LOCATION_TO_ADJ
our %LOCATION_TO_ADJ = (
  # continents/regions (note: Australia is a country also)
  'South America' => [ 'South American' ],
  'North America' => [ 'North American' ],
  'Central America' => [ 'Central American' ],
  'Asia' => [ 'Asian' ],
  'Africa' => [ 'African' ],
  'Europe' => [ 'European' ],

  # common regions
  'Alaska' => [ 'Alaskan' ],
  'Hawaii' => [ 'Hawaiian' ],
  'Scotland' => [ 'Scottish' ],

  # countries
  'Afghanistan' => [ 'Afghan' ],
  'Albania' => [ 'Albanian' ],
  'Algeria' => [ 'Algerian' ],
  'American Samoa' => [ 'American Samoan' ],
  'Andorra' => [ 'Andorran' ],
  'Angola' => [ 'Angolan' ],
  'Anguilla' => [ 'Anguillan' ],
  'Antigua and Barbuda' => [ 'Antiguan', 'Barbudan' ],
  'Argentina' => [ 'Argentinian', 'Argentine' ],
  'Armenia' => [ 'Armenian' ],
  'Aruba' => [ 'Aruban' ],
  'Australia' => [ 'Australian' ],
  'Austria' => [ 'Austrian' ],
  'Azerbaijan' => [ 'Azerbaijani' ],
  'Bahrain' => [ 'Bahraini' ],
  'Barbados' => [ 'Barbadian' ],
  'Belarus' => [ 'Belarusian' ],
  'Belgium' => [ 'Belgian' ],
  'Belize' => [ 'Belizean' ],
  'Benin' => [ 'Beninese' ],
  'Bermuda' => [ 'Bermudian' ],
  'Bhutan' => [ 'Bhutanese' ],
  'Bolivia' => [ 'Bolivian' ],
  'Bosnia' => [ 'Bosnian' ],
  'Bosnia and Herzegovina' => [ 'Bosnian' ],
  'Botswana' => [ 'Motswana', 'Batswana' ],
  'Brazil' => [ 'Brazilian' ],
  'England' => [ 'English', 'British' ],
  'United Kingdom' => [ 'British', 'English' ],
  'British Virgin Islands' => [ 'British Virgin Islander' ],
  'Brunei' => [ 'Bruneian' ],
  'Bulgaria' => [ 'Bulgarian' ],
  'Burkina Faso' => [ 'Burkinabe' ],
  'Burma' => [ 'Burmese' ],
  'Burundi' => [ 'Burundi' ],
  'Cambodia' => [ 'Cambodian' ],
  'Cameroon' => [ 'Cameroonian' ],
  'Canada' => [ 'Canadian' ],
  'Cape Verde' => [ 'Cape Verdean' ],
  'Cayman Islands' => [ 'Caymanian' ],
  'Central African Republic' => [ 'Central African' ],
  'Chad' => [ 'Chadean' ],
  'Chile' => [ 'Chilean' ],
  'China' => [ 'Chinese' ],
  'Cocos Islands' => [ 'Cocos Islander' ],
  'Keeling Islands' => [ 'Cocos Islander' ],
  'Cocos (Keeling) Islands' => [ 'Cocos Islander' ],
  'Colombia' => [ 'Colombian' ],
  'Comoros' => [ 'Comoran' ],
  'Congo' => [ 'Congolese' ],
  'Congo, Republic of the' => [ 'Congolese' ],
  'Cook Islands' => [ 'Cook Islander' ],
  'Cote d\'Ivoire' => [ 'Ivorian' ],
  'Costa Rica' => [ 'Costa Rican' ],
  'Croatia' => [ 'Croatian' ],
  'Cuba' => [ 'Cuban' ],
  'Cyprus' => [ 'Cypriot' ],
  'Czech Republic' => [ 'Czech', 'Czechoslovakian' ],
  'Denmark' => [ 'Danish' ],
  'Djibouti' => [ 'Djiboutian' ],
  'Dominica' => [ 'Dominican' ],
  'Dominican Republic' => [ 'Dominican' ],
  'East Timor' => [ 'East Timorese' ],
  'Ecuador' => [ 'Ecuadorian' ],
  'Equatorial Guinea' => [ 'Equatorial Guinean', 'Equatorial Guinea' ],
  'Egypt' => [ 'Egyptian' ],
  'El Salvador' => [ 'Salvadoran' ],
  'Eritrea' => [ 'Eritrean' ],
  'Estonia' => [ 'Estonian' ],
  'Ethiopia' => [ 'Ethiopian' ],
  'Faroe Islands' => [ 'Faroese' ],
  'Fiji' => [ 'Fijian' ],
  'Finland' => [ 'Finnish' ],
  'France' => [ 'French' ],
  'French Guiana' => [ 'French Guianese' ],
  'French Polynesia' => [ 'French Polynesian' ],
  'Gabon' => [ 'Gabonese' ],
  'Georgia' => [ 'Georgian' ],
  'Gambia' => [ 'Gambian' ],
  'The Gambia' => [ 'Gambian' ],
  'Germany' => [ 'German' ],
  'Ghana' => [ 'Ghanaian' ],
  'Greece' => [ 'Greek' ],
  'Greenland' => [ 'Greenlandic' ],
  'Grenada' => [ 'Grenadian' ],
  'Guam' => [ 'Guamanian' ],
  'Guatemala' => [ 'Guatemalan' ],
  'Guernsey' => [ 'Channel Islander' ],
  'Guinea' => [ 'Guinean' ],
  'Guinea-Bissau' => [ 'Guinea-Bissauan' ],
  'Guyana' => [ 'Guyanese' ],
  'Haiti' => [ 'Haitian' ],
  'Netherlands' => [ 'Dutch' ],
  'Honduras' => [ 'Honduran' ],
  'Hungary' => [ 'Hungarian' ],
  'Iceland' => [ 'Icelandic' ],
  'India' => [ 'Indian' ],
  'Indonesia' => [ 'Indonesian' ],
  'Iran' => [ 'Iranian' ],
  'Iraq' => [ 'Iraqi' ],
  'Ireland' => [ 'Irish' ],
  'Israel' => [ 'Israeli' ],
  'Isle of Man' => [ 'Manx' ],
  'Man, Isle of' => [ 'Manx' ],
  'Italy' => [ 'Italian' ],
  'Jamaica' => [ 'Jamaican' ],
  'Japan' => [ 'Japanese' ],
  'Jordan' => [ 'Jordanian' ],
  'Kazakhstan' => [ 'Kazakstani' ],
  'Kenya' => [ 'Kenyan' ],
  'Kiribati' => [ 'Kiribati' ],
  'Korea' => [ 'Korean' ],
  'South Korea' => [ 'South Korean' ],
  'Korea, South' => [ 'South Korean' ],
  'Kuwait' => [ 'Kuwaiti' ],
  'Kyrgyzstan' => [ 'Kyrgyz' ],
  'Laos' => [ 'Laotian', 'Lao' ],
  'Latvia' => [ 'Latvian' ],
  'Lebanon' => [ 'Lebanese' ],
  'Lesotho' => [ 'Basotho' ],
  'Liberia' => [ 'Liberian' ],
  'Libya' => [ 'Libyan' ],
  'Lithuania' => [ 'Lithuanian' ],
  'Macedonia' => [ 'Macedonian' ],
  'Macedonia, The Former Yugoslav Republic of' => [ 'Macedonian' ],
  'Madagascar' => [ 'Malagasy' ],
  'Malawi' => [ 'Malawian' ],
  'Malaysia' => [ 'Malaysian' ],
  'Maldives' => [ 'Maldivian' ],
  'Mali' => [ 'Malian' ],
  'Malta' => [ 'Maltese' ],
  'Marshall Islands' => [ 'Marshallese' ],
  'Martinique' => [ 'Martiniquais' ],
  'Mauritania' => [ 'Mauritanian' ],
  'Mauritius' => [ 'Mauritian' ],
  'Mayotte' => [ 'Mahoran' ],
  'Mexico' => [ 'Mexican' ],
  'Micronesia, Federated States of' => [ 'Micronesian', 'Kosrae', 'Kosraes', 'Pohnpeian', 'Pohnpeians', 'Trukese', 'Yapese' ],
  'Micronesia' => [ 'Micronesian', 'Kosrae', 'Kosraes', 'Pohnpeian', 'Pohnpeians', 'Trukese', 'Yapese' ],
  'Moldova' => [ 'Moldovan' ],
  'Monaco' => [ 'Monacan', 'Monegasque' ],
  'Mongolia' => [ 'Mongolian' ],
  'Montserrat' => [ 'Montserratian' ],
  'Morocco' => [ 'Moroccan' ],
  'Mozambique' => [ 'Mozambican' ],
  'Namibia' => [ 'Namibian' ],
  'Nauru' => [ 'Nauruan' ],
  'Nepal' => [ 'Nepalese', 'Nepali' ],
  'Netherlands Antilles' => [ 'Netherlands Antillean' ],
  'New Caledonia' => [ 'New Caledonian' ],
  'Nicaragua' => [ 'Nicaraguan' ],
  'Niger' => [ 'Nigerien' ],
  'Nigeria' => [ 'Nigerian' ],
  'Niue' => [ 'Niuean' ],
  'Norfolk Island' => [ 'Norfolk Islander' ],
  'North Korea' => [ 'North Korean' ],
  'Norway' => [ 'Norwegian' ],
  'Oman' => [ 'Omani' ],
  'Pakistan' => [ 'Pakistani' ],
  'Palau' => [ 'Palauan' ],
  'Panama' => [ 'Panamanian' ],
  'New Guinea' => [ 'New Guinean' ],
  'Papua New Guinea' => [ 'Papua New Guinean' ],
  'Paraguay' => [ 'Paraguayan' ],
  'Peru' => [ 'Peruvian' ],
  'Philippines' => [ 'Philippine' ],
  'Pitcairn Islands' => [ 'Pitcairn Islander' ],
  'Poland' => [ 'Polish' ],
  'Portugal' => [ 'Portuguese' ],
  'Puerto Rico' => [ 'Puerto Rican' ],
  'Qatar' => [ 'Qatari' ],
  'Reunion' => [ 'Reunionese' ],
  'Romania' => [ 'Romanian', 'Rumanian' ],
  'Russia' => [ 'Russian' ],
  'Rwanda' => [ 'Rwandan' ],
  'Saint Helena' => [ 'Saint Helenian' ],
  'Saint Lucia' => [ 'Saint Lucian' ],
  'Saint Vincent and the Grenadines' => [ 'Saint Vincentian', 'Vincentian' ],
  'San Marino' => [ 'Sammarinese' ],
  'Sao Tome' => [ 'Sao Tomean' ],
  'Sao Tome and Principe' => [ 'Sao Tomean' ],
  'Saudi Arabia' => [ 'Saudi Arabian' ],
  'Senegal' => [ 'Senegalese' ],
  'Yugoslavia' => [ 'Serbian' ],
  'Sierra Leone' => [ 'Sierra Leonean' ],
  'Slovakia' => [ 'Slovak' ],
  'Slovenia' => [ 'Slovenian' ],
  'Solomon Islands' => [ 'Solomon Islander' ],
  'Somalia' => [ 'Somali' ],
  'South Africa' => [ 'South African' ],
  'Spain' => [ 'Spanish' ],
  'Sri Lanka' => [ 'Sri Lankan' ],
  'Sudan' => [ 'Sudanese' ],
  'Suriname' => [ 'Surinamese' ],
  'Swaziland' => [ 'Swazi' ],
  'Sweden' => [ 'Swedish' ],
  'Switzerland' => [ 'Swiss' ],
  'Syria' => [ 'Syrian' ],
  'Taiwan' => [ 'Taiwanese' ],
  'Tajikistan' => [ 'Tajik' ],
  'Tanzania' => [ 'Tanzanian' ],
  'Thailand' => [ 'Thai' ],
  'Bahamas' => [ 'Bahamian' ],
  'The Bahamas' => [ 'Bahamian' ],
  'Togo' => [ 'Togolese' ],
  'Trinidad' => [ 'Trinidadian' ],
  'Tobago' => [ 'Tobagonian' ],
  'Trinidad and Tobago' => [ 'Trinidadian', 'Tobagonian' ],
  'Tunisia' => [ 'Tunisian' ],
  'Turkey' => [ 'Turkish' ],
  'Turkmenistan' => [ 'Turkmen' ],
  'Uganda' => [ 'Ugandan' ],
  'Ukraine' => [ 'Ukrainian', 'Ukranian' ],
  'United Arab Emirates' => [ 'Emirian' ],
  'United States' => [ 'American' ],
  'Uruguay' => [ 'Uruguayan' ],
  'Uzbekistan' => [ 'Uzbek' ],
  'Vanuatu' => [ 'Ni-Vanuatu' ],
  'Venezuela' => [ 'Venezuelan' ],
  'Vietnam' => [ 'Vietnamese' ],
  'Virgin Islands' => [ 'Virgin Islander' ],
  'Wallis' => [ 'Wallisian' ],
  'Futuna' => [ 'Futunan' ],
  'Wallis and Futuna' => [ 'Wallisian', 'Futunan', 'Wallis and Futuna Islander' ],
  'Western Sahara' => [ 'Sahrawian', 'Sahraouian' ],
  'Samoa' => [ 'Western Samoan' ],
  'Yemen' => [ 'Yemeni' ],
  'Congo, Democratic Republic of the' => [ 'Zairian' ],
  'Zambia' => [ 'Zambia' ],
  'Zimbabwe' => [ 'Zimbabwean' ],
);
#>
#< regexp: COUNTRY
our $COUNTRY = qr{
         Afghanistan|
         Albania|
         Algeria|
         Andorra|
         Angola|
         Antigua\s+and\s+Barbuda|Antigua|Barbuda|
         Argentina|
         Armenia|
         Australia|
         Austria|
         Azerbaijan|
         Bahamas,\s+The|Bahamas|
         Bahrain|
         Bangladesh|
         Barbados|
         Belarus|
         Belgium|
         Belize|
         Benin|
         Bhutan|
         Bolivia|
         Bosnia\s+and\s+Herzegovina|Bosnia|Herzegovina|
         Botswana|
         Brazil|
         Brunei|
         Bulgaria|
         Burkina\s+Faso|
         Burundi|
         Cambodia|
         Cameroon|
         Canada|
         Cape\s+Verde|
         Central\s+African\s+Republic|
         Chad|
         Chile|
         China|
         Colombia|
         Comoros|
         Congo,\s+Republic\s+of\s+the|Congo|
         Congo,\s+Democratic\s+Republic\s+of\s+the|Zaire|
         Costa\s+Rica|
         Cote\s+d\'Ivoire|Ivory\s+Coast|
         Croatia|
         Cuba|
         Cyprus|
         Czech Republic|
         Denmark|
         Djibouti|
         Dominica|
         Dominican\s+Republic|
         Ecuador|
         Egypt|
         El\s+Salvador|
         Equatorial\s+Guinea|
         Eritrea|
         Estonia|
         Ethiopia|
         Fiji|
         Finland|
         France|
         Gabon|
         Gambia,\s+The|Gambia|
         Georgia|
         Germany|
         Ghana|
         Greece|
         Grenada|
         Guatemala|
         Guinea|
         Guinea-Bissau|Guinea\s+Bissau|
         Guyana|
         Haiti|
         Honduras|
         Hungary|
         Iceland|
         India|
         Indonesia|
         Iran|
         Iraq|
         Ireland|
         Israel|
         Italy|
         Jamaica|
         Japan|
         Jordan|
         Kazakhstan|
         Kenya|
         Kiribati|
         Korea,\s+North|North\s+Korea|
         Korea,\s+South|South\s+Korea|Korea|
         Kuwait|
         Kyrgyzstan|
         Laos|
         Latvia|
         Lebanon|
         Lesotho|
         Liberia|
         Libya|
         Liechtenstein|
         Lithuania|
         Luxembourg|
         Macedonia|
         Madagascar|
         Malawi|
         Malaysia|
         Maldives|
         Mali|
         Malta|
         Mauritania|
         Mauritius|
         Mexico|
         Micronesia,\s+Federated\s+States\s+of|Micronesia|
         Moldova|
         Monaco|
         Mongolia|
         Morocco|
         Mozambique|
         Myanmar|Burma|
         Namibia|
         Nauru|
         Nepal|
         Netherlands,\s+The|Netherlands|
         New\s+Zealand|
         Nicaragua|
         Niger|
         Nigeria|
         Norway|
         Oman|
         Pakistan|
         Palau|
         Panama|
         Papua\s+New\s+Guinea|
         Paraguay|
         Peru|
         Philippines,\s+The|Philippines|
         Poland|
         Portugal|
         Qatar|
         Romania|
         Russia|
         Rwanda|
         Saint\s+Kitts\s+and\s+Nevis|
         Saint\s+Lucia|
         Saint\s+Vincent\s+and\s+the\s+Grenadines|
         Samoa|
         San\s+Marino|
         Sao\s+Tome\s+and\s+Principe|
         Saudi\s+Arabia|
         Senegal|
         Seychelles|
         Sierra\s+Leone|
         Singapore|
         Slovakia|
         Slovenia|
         Solomon\s+Islands|
         Somalia|
         South\s+Africa|
         Spain|
         Sri\s+Lanka|
         Sudan|
         Suriname|
         Swaziland|
         Sweden|
         Switzerland|
         Syria|
         Taiwan|
         Tajikistan|
         Tanzania|
         Thailand|
         Togo|
         Tonga|
         Trinidad\s+and\s+Tobago|Trinidad|Tobago|
         Tunisia|
         Turkey|
         Turkmenistan|
         Tuvalu|
         Uganda|
         Ukraine|
         United\s+Arab\s+Emirates|U\.?A\.?E\.?|
         United\s+Kingdom|Great\s+Britain|England|
         United\s+States|U\.?S\.?(A\.?)?|
         Uruguay|
         Uzbekistan|
         Vanuatu|
         Vatican\s+City|Holy\s+See|
         Venezuela|
         Vietnam|
         Western\s+Sahara|
         Yemen|
         Yugoslavia|Serbia|Montenegro|
         Zambia|
         Zimbabwe}ox;
#>

#< exactify_location
my $relative_location_marker = qr{(?:northern|southern|eastern|western|northeastern|northwestern|southeastern|southwestern|central|north\s+central|south\s+central|east\s+central|west\s+central|northern\s+central|southern\s+central|eastern\s+central|western\s+central|northeastern\s+central|northwestern\s+central|southeastern\s+central|southwestern\s+central|upper|lower)}o;

sub exactify_location {
    my $s = shift;

    return unless $s;

    # take care of things like q317 'in the Marianas'
    # q359 'in east central Florida', and q499 'in northern South America'
    $s =~ s/^(in (?:the|$relative_location_marker))/<<$1>>/;

    # take care of things like q466 'in Scotland'
    $s =~ s/^in /<<in>> /;

    # take care of things like q1076 'in southwestern Asia; flows'
    $s =~ s/; .*$//g;

    # take care of things like q1199 'in South Carolina that flows'
    $s =~ s/ that .*$//g;

    # map adjectives to noun form, e.g. q270 'South American'
    $s = $ADJ_TO_LOCATION{$1}->[0] 
	if $s =~ /^($ADJ_TO_LOCATION_keys)s?$/g;

    # take care of things like q249 'Ancient Egypt'
    $s =~ s/^Ancient //i;

    # take care of things like q1099 'Planet Mars'
    $s =~ s/^Planet //i;

    # clean up things like 'on the northeastern coast of Central
    # America', which is the location of Belize as extract from
    # WordNet gloss
    $s =~ s/^([a-z]+ )+of (?=[A-Z])//;

    return $s;
}
#>

#< regexp: POSTAL_CODE
our $POSTAL_CODE = qr{(?:AL|AK|AZ|AR|CA|CO|CT|DE|DC|FL|GA|GU|HI|ID|IL|IN|IA|KS|KY|LA|ME|MD|MA|MI|MN|MS|MO|MT|NE|NV|NH|NJ|NM|NY|NC|ND|OH|OK|OR|PA|PR|RI|SC|SD|TN|TX|UT|VT|VA|VI|WA|WV|WI|WY)}o;
#>
#< regexp: STATE
our $STATE = qr{(?:Alabama|Alaska|Arizona|Arkansas|California|Colorado|Connecticut|Delaware|District\s+of\s+Columbia|Florida|Georgia|Guam|Hawaii|Idaho|Illinois|Indiana|Iowa|Kansas|Kentucky|Louisiana|Maine|Maryland|Massachusetts|Michigan|Minnesota|Mississippi|Missouri|Montana|Nebraska|Nevada|New\s+Hampshire|New\s+Jersey|New\s+Mexico|New\s+York|North\s+Carolina|North\s+Dakota|Ohio|Oklahoma|Oregon|Pennsylvania|Puerto\s+Rico|Rhode\s+Island|South\s+Carolina|South\s+Dakota|Tennessee|Texas|Utah|Vermont|Virginia|Virgin\s+Islands|Washington|West\s+Virginia|Wisconsin|Wyoming)}o;
#>
#< hash: STATE_TO_POSTAL_CODE
our %STATE_TO_POSTAL_CODE = (
  'Alabama' => [ 'AL' ],
  'Alaska' => [ 'AK' ],
  'Arizona' => [ 'AZ' ],
  'Arkansas' => [ 'AR' ],
  'California' => [ 'CA' ],
  'Colorado' => [ 'CO' ],
  'Connecticut' => [ 'CT' ],
  'Delaware' => [ 'DE' ],
  'District of Columbia' => [ 'DC' ],
  'Florida' => [ 'FL' ],
  'Georgia' => [ 'GA' ],
  'Guam' => [ 'GU' ],
  'Hawaii' => [ 'HI' ],
  'Idaho' => [ 'ID' ],
  'Illinois' => [ 'IL' ],
  'Indiana' => [ 'IN' ],
  'Iowa' => [ 'IA' ],
  'Kansas' => [ 'KS' ],
  'Kentucky' => [ 'KY' ],
  'Louisiana' => [ 'LA' ],
  'Maine' => [ 'ME' ],
  'Maryland' => [ 'MD' ],
  'Massachusetts' => [ 'MA' ],
  'Michigan' => [ 'MI' ],
  'Minnesota' => [ 'MN' ],
  'Mississippi' => [ 'MS' ],
  'Missouri' => [ 'MO' ],
  'Montana' => [ 'MT' ],
  'Nebraska' => [ 'NE' ],
  'Nevada' => [ 'NV' ],
  'New Hampshire' => [ 'NH' ],
  'New Jersey' => [ 'NJ' ],
  'New Mexico' => [ 'NM' ],
  'New York' => [ 'NY' ],
  'North Carolina' => [ 'NC' ],
  'North Dakota' => [ 'ND' ],
  'Ohio' => [ 'OH' ],
  'Oklahoma' => [ 'OK' ],
  'Oregon' => [ 'OR' ],
  'Pennsylvania' => [ 'PA' ],
  'Puerto Rico' => [ 'PR' ],
  'Rhode Island' => [ 'RI' ],
  'South Carolina' => [ 'SC' ],
  'South Dakota' => [ 'SD' ],
  'Tennessee' => [ 'TN' ],
  'Texas' => [ 'TX' ],
  'Utah' => [ 'UT' ],
  'Vermont' => [ 'VT' ],
  'Virginia' => [ 'VA' ],
  'Virgin Islands' => [ 'VI' ],
  'Washington' => [ 'WA' ],
  'West Virginia' => [ 'WV' ],
  'Wisconsin' => [ 'WI' ],
  'Wyoming' => [ 'WY' ],
);
#>
#< hash: POSTAL_CODE_TO_STATE
our %POSTAL_CODE_TO_STATE = (
  'AL' => [ 'Alabama' ],
  'AK' => [ 'Alaska' ],
  'AZ' => [ 'Arizona' ],
  'AR' => [ 'Arkansas' ],
  'CA' => [ 'California' ],
  'CO' => [ 'Colorado' ],
  'CT' => [ 'Connecticut' ],
  'DE' => [ 'Delaware' ],
  # don't expand 'Washington, DC' to 'Washington, District of Columbia'
  'DC' => [ 'DC', 'District of Columbia' ],
  'FL' => [ 'Florida' ],
  'GA' => [ 'Georgia' ],
  'GU' => [ 'Guam' ],
  'HI' => [ 'Hawaii' ],
  'ID' => [ 'Idaho' ],
  'IL' => [ 'Illinois' ],
  'IN' => [ 'Indiana' ],
  'IA' => [ 'Iowa' ],
  'KS' => [ 'Kansas' ],
  'KY' => [ 'Kentucky' ],
  'LA' => [ 'Louisiana' ],
  'ME' => [ 'Maine' ],
  'MD' => [ 'Maryland' ],
  'MA' => [ 'Massachusetts' ],
  'MI' => [ 'Michigan' ],
  'MN' => [ 'Minnesota' ],
  'MS' => [ 'Mississippi' ],
  'MO' => [ 'Missouri' ],
  'MT' => [ 'Montana' ],
  'NE' => [ 'Nebraska' ],
  'NV' => [ 'Nevada' ],
  'NH' => [ 'New Hampshire' ],
  'NJ' => [ 'New Jersey' ],
  'NM' => [ 'New Mexico' ],
  'NY' => [ 'New York' ],
  'NC' => [ 'North Carolina' ],
  'ND' => [ 'North Dakota' ],
  'OH' => [ 'Ohio' ],
  'OK' => [ 'Oklahoma' ],
  'OR' => [ 'Oregon' ],
  'PA' => [ 'Pennsylvania' ],
  'PR' => [ 'Puerto Rico' ],
  'RI' => [ 'Rhode Island' ],
  'SC' => [ 'South Carolina' ],
  'SD' => [ 'South Dakota' ],
  'TN' => [ 'Tennessee' ],
  'TX' => [ 'Texas' ],
  'UT' => [ 'Utah' ],
  'VT' => [ 'Vermont' ],
  'VA' => [ 'Virginia' ],
  'VI' => [ 'Virgin Islands' ],
  'WA' => [ 'Washington' ],
  'WV' => [ 'West Virginia' ],
  'WI' => [ 'Wisconsin' ],
  'WY' => [ 'Wyoming' ],
);
#>
#< hash: STATE_TO_ABBREV
our %STATE_TO_ABBREV = (
  'Alabama' => [ 'Ala.' ],
  'Alaska' => [ 'Alaska' ],
  'Arizona' => [ 'Ariz.' ],
  'Arkansas' => [ 'Ark.' ],
  'California' => [ 'Calif.' ],
  'Colorado' => [ 'Colo.' ],
  'Connecticut' => [ 'Conn.' ],
  'Delaware' => [ 'Del.' ],
  'District of Columbia' => [ 'D.C.' ],
  'Florida' => [ 'Fla.' ],
  'Georgia' => [ 'Ga.' ],
  'Guam' => [ 'Guam' ],
  'Hawaii' => [ 'Hawaii' ],
  'Idaho' => [ 'Idaho' ],
  'Illinois' => [ 'Ill.' ],
  'Indiana' => [ 'Ind.' ],
  'Iowa' => [ 'Iowa' ],
  'Kansas' => [ 'Kans.' ],
  'Kentucky' => [ 'Ky.' ],
  'Louisiana' => [ 'La.' ],
  'Maine' => [ 'Maine' ],
  'Maryland' => [ 'Md.' ],
  'Massachusetts' => [ 'Mass.' ],
  'Michigan' => [ 'Mich.' ],
  'Minnesota' => [ 'Minn.' ],
  'Mississippi' => [ 'Miss.' ],
  'Missouri' => [ 'Mo.' ],
  'Montana' => [ 'Mont.' ],
  'Nebraska' => [ 'Nebr.' ],
  'Nevada' => [ 'Nev.' ],
  'New Hampshire' => [ 'N.H.' ],
  'New Jersey' => [ 'N.J.' ],
  'New Mexico' => [ 'N.M.' ],
  'New York' => [ 'N.Y.' ],
  'North Carolina' => [ 'N.C.' ],
  'North Dakota' => [ 'N.D.' ],
  'Ohio' => [ 'Ohio' ],
  'Oklahoma' => [ 'Okla.' ],
  'Oregon' => [ 'Ore.' ],
  'Pennsylvania' => [ 'Pa.' ],
  'Puerto Rico' => [ 'P.R.' ],
  'Rhode Island' => [ 'R.I.' ],
  'South Carolina' => [ 'S.C.' ],
  'South Dakota' => [ 'S.D.' ],
  'Tennessee' => [ 'Tenn.' ],
  'Texas' => [ 'Tex.' ],
  'Utah' => [ 'Utah' ],
  'Vermont' => [ 'Vt.' ],
  'Virginia' => [ 'Va.' ],
  'Virgin Islands' => [ 'V.I.' ],
  'Washington' => [ 'Wash.' ],
  'West Virginia' => [ 'W.Va.' ],
  'Wisconsin' => [ 'Wis.' ],
  'Wyoming' => [ 'Wyo.' ],
);
#>
#< hash: ABBREV_TO_STATE
our %ABBREV_TO_STATE = (
  'Ala.' => [ 'Alabama' ],
  'Alaska' => [ 'Alaska' ],
  'Ariz.' => [ 'Arizona' ],
  'Ark.' => [ 'Arkansas' ],
  'Calif.' => [ 'California' ],
  'Colo.' => [ 'Colorado' ],
  'Conn.' => [ 'Connecticut' ],
  'Del.' => [ 'Delaware' ],
  # 'Washington, DC' is the cannoncial form
  'D.C.' => [ 'DC', 'District of Columbia' ],
  'Fla.' => [ 'Florida' ],
  'Ga.' => [ 'Georgia' ],
  'Guam' => [ 'Guam' ],
  'Hawaii' => [ 'Hawaii' ],
  'Idaho' => [ 'Idaho' ],
  'Ill.' => [ 'Illinois' ],
  'Ind.' => [ 'Indiana' ],
  'Iowa' => [ 'Iowa' ],
  'Kans.' => [ 'Kansas' ],
  'Ky.' => [ 'Kentucky' ],
  'La.' => [ 'Louisiana' ],
  'Maine' => [ 'Maine' ],
  'Md.' => [ 'Maryland' ],
  'Mass.' => [ 'Massachusetts' ],
  'Mich.' => [ 'Michigan' ],
  'Minn.' => [ 'Minnesota' ],
  'Miss.' => [ 'Mississippi' ],
  'Mo.' => [ 'Missouri' ],
  'Mont.' => [ 'Montana' ],
  'Nebr.' => [ 'Nebraska' ],
  'Nev.' => [ 'Nevada' ],
  'N.H.' => [ 'New Hampshire' ],
  'N.J.' => [ 'New Jersey' ],
  'N.M.' => [ 'New Mexico' ],
  'N.Y.' => [ 'New York' ],
  'N.C.' => [ 'North Carolina' ],
  'N.D.' => [ 'North Dakota' ],
  'Ohio' => [ 'Ohio' ],
  'Okla.' => [ 'Oklahoma' ],
  'Ore.' => [ 'Oregon' ],
  'Pa.' => [ 'Pennsylvania' ],
  'P.R.' => [ 'Puerto Rico' ],
  'R.I.' => [ 'Rhode Island' ],
  'S.C.' => [ 'South Carolina' ],
  'S.D.' => [ 'South Dakota' ],
  'Tenn.' => [ 'Tennessee' ],
  'Tex.' => [ 'Texas' ],
  'Utah' => [ 'Utah' ],
  'Vt.' => [ 'Vermont' ],
  'Va.' => [ 'Virginia' ],
  'V.I.' => [ 'Virgin Islands' ],
  'Wash.' => [ 'Washington' ],
  'W.Va.' => [ 'West Virginia' ],
  'Wis.' => [ 'Wisconsin' ],
  'Wyo.' => [ 'Wyoming' ],
);
#>

#< regexp: CANADIAN_PROVINCE
our $CANADIAN_PROVINCE = qr{
    Alberta|
    Nunavut|
    British\s+Columbia|
    Ontario|
    Manitoba|
    Prince\s+Edward\s+Island|
    New\s+Brunswick|
    Quebec|
    Newfoundland\s+and\s+Labrador|Newfoundland|Labrador|
    Saskatchewan|
    Northwest\s+Territories|
    Yukon|
    Nova\s+Scotia}ox;
#>
#< regexp: COLLEGE
our $COLLEGE = qr{(?:Abilene\s+Christian|Abilene\s+Christian\s+University|Adams\s+State|Adams\s+State\s+College|Adelphi|Adelphi\s+University|Adrian|Adrian\s+College|Agnes\s+Scott|Agnes\s+Scott\s+College|Alabama\s+Agricultural\s+and\s+Mechanical|Alabama\s+Agricultural\s+and\s+Mechanical\s+University|Alabama\s+State|Alabama\s+State\s+University|Alaska\s+Pacific|Alaska\s+Pacific\s+University|Albany\s+State|Albany\s+State\s+University|Albertson|Albertson\s+College|Albertus\s+Magnus|Albertus\s+Magnus\s+College|Albion|Albion\s+College|Albright|Albright\s+College|Alcorn\s+State|Alcorn\s+State\s+University|Alfred|Alfred\s+University|Alice\s+Lloyd|Alice\s+Lloyd\s+College|Allegheny|Allegheny\s+College|Allen|Allen\s+University|Alliant\s+International|Alliant\s+International\s+University|Alma|Alma\s+College|Alvernia|Alvernia\s+College|Alverno|Alverno\s+College|American|American\s+International|American\s+International\s+College|American\s+University|Amherst|Amherst\s+College|Anderson|Anderson\s+College|Anderson\s+University|Andrews|Andrews\s+University|Angelo\s+State|Angelo\s+State\s+University|Anna\s+Maria|Anna\s+Maria\s+College|Antioch|Antioch\s+College|Appalachian\s+State|Appalachian\s+State\s+University|Aquinas|Aquinas\s+College|Arcadia|Arcadia\s+University|Arizona\s+State|Arizona\s+State\s+University|Arizona\s+State\s+University\s+West|Arkansas\s+Baptist|Arkansas\s+Baptist\s+College|Arkansas\s+State|Arkansas\s+State\s+University|Arkansas\s+Tech|Arkansas\s+Tech\s+University|Armstrong\s+Atlantic\s+State|Armstrong\s+Atlantic\s+State\s+University|Art\s+Academy\s+of\s+Cincinnati|Art\s+Center|Art\s+Center\s+College\s+of\s+Design|Art\s+Institute\s+of\s+Southern\s+California|Asbury|Asbury\s+College|Ashland|Ashland\s+University|Assumption|Assumption\s+College|Atlanta|Atlanta\s+College\s+of\s+Art|Atlantic\s+Union|Atlantic\s+Union\s+College|Auburn|Auburn\s+University|Auburn\s+University--Montgomery|Auburn\s+University\s*[-:,]+\s*Montgomery|Augsburg|Augsburg\s+College|Augusta\s+State|Augusta\s+State\s+University|Augustana|Augustana\s+College|Aurora|Aurora\s+University|Austin|Austin\s+College|Austin\s+Peay\s+State|Austin\s+Peay\s+State\s+University|Averett|Averett\s+University|Avila|Avila\s+College|Azusa\s+Pacific|Azusa\s+Pacific\s+University|Babson|Babson\s+College|Baker|Baker\s+College\s+of\s+Flint|Baker\s+University|Baldwin-Wallace|Baldwin-Wallace\s+College|Ball\s+State|Ball\s+State\s+University|Barber\s+Scotia|Barber\s+Scotia\s+College|Bard|Bard\s+College|Barnard|Barnard\s+College|Barry|Barry\s+University|Barton|Barton\s+College|Bates|Bates\s+College|Bay\s+Path|Bay\s+Path\s+College|Baylor|Baylor\s+University|Becker|Becker\s+College|Belhaven|Belhaven\s+College|Bellarmine|Bellarmine\s+University|Bellevue|Bellevue\s+University|Belmont|Belmont\s+Abbey|Belmont\s+Abbey\s+College|Belmont\s+University|Beloit|Beloit\s+College|Bemidji\s+State|Bemidji\s+State\s+University|Benedict|Benedict\s+College|Benedictine|Benedictine\s+College|Benedictine\s+University|Benjamin\s+Franklin\s+Institute\s+of\s+Technology|Bennett|Bennett\s+College|Bennington|Bennington\s+College|Bentley|Bentley\s+College|Berea|Berea\s+College|Berkeley|Berklee|Berklee\s+College\s+of\s+Music|Berry|Berry\s+College|Bethany|Bethany\s+College|Bethel|Bethel\s+College|Bethune-Cookman|Bethune-Cookman\s+College|Biola|Biola\s+University|Birmingham-Southern|Birmingham-Southern\s+College|Black\s+Hills\s+State|Black\s+Hills\s+State\s+University|Blackburn|Blackburn\s+College|Bloomfield|Bloomfield\s+College|Bloomsburg|Bloomsburg\s+University\s+of\s+Pennsylvania|Blue\s+Mountain|Blue\s+Mountain\s+College|Bluefield|Bluefield\s+College|Bluefield\s+State|Bluefield\s+State\s+College|Bluffton|Bluffton\s+College|Boise\s+State|Boise\s+State\s+University|Boricua|Boricua\s+College|Boston|Boston\s+Architectural\s+Center|Boston\s+College|Boston\s+Conservatory|Boston\s+University|Bowdoin|Bowdoin\s+College|Bowie\s+State|Bowie\s+State\s+University|Bowling\s+Green\s+State|Bowling\s+Green\s+State\s+University|Bradley|Bradley\s+University|Brandeis|Brandeis\s+University|Brenau|Brenau\s+University|Brescia|Brescia\s+University|Brevard|Brevard\s+College|Brewton-Parker|Brewton-Parker\s+College|Briar\s+Cliff|Briar\s+Cliff\s+University|Bridgewater|Bridgewater\s+College|Bridgewater\s+State|Bridgewater\s+State\s+College|Brigham\s+Young\s+University--Hawaii|Brigham\s+Young\s+University--Provo|Brigham\s+Young\s+University\s*[-:,]+\s*Hawaii|Brigham\s+Young\s+University\s*[-:,]+\s*Provo|Brown|Brown\s+University|Bryan|Bryan\s+College|Bryant|Bryant\s+College|Bryn\s+Athyn|Bryn\s+Athyn\s+College|Bryn\s+Mawr|Bryn\s+Mawr\s+College|Bucknell|Bucknell\s+University|Buena\s+Vista|Buena\s+Vista\s+University|Buffalo\s+State|Buffalo\s+State\s+College|Burlington|Burlington\s+College|Butler|Butler\s+University|CMU|CUNY--Baruch\s+College|CUNY--Brooklyn\s+College|CUNY--City\s+College|CUNY--College\s+of\s+Staten\s+Island|CUNY--Hunter\s+College|CUNY--Lehman\s+College|CUNY--Medgar\s+Evers\s+College|CUNY--New\s+York\s+City\s+Technical\s+College|CUNY--Queens\s+College|CUNY--York\s+College|CUNY\s*[-:,]+\s*Baruch\s+College|CUNY\s*[-:,]+\s*Brooklyn\s+College|CUNY\s*[-:,]+\s*City\s+College|CUNY\s*[-:,]+\s*College\s+of\s+Staten\s+Island|CUNY\s*[-:,]+\s*Hunter\s+College|CUNY\s*[-:,]+\s*Lehman\s+College|CUNY\s*[-:,]+\s*Medgar\s+Evers\s+College|CUNY\s*[-:,]+\s*New\s+York\s+City\s+Technical\s+College|CUNY\s*[-:,]+\s*Queens\s+College|CUNY\s*[-:,]+\s*York\s+College|Cabrini|Cabrini\s+College|Cal\s+Poly--San\s+Luis\s+Obispo|Cal\s+Poly\s*[-:,]+\s*San\s+Luis\s+Obispo|Cal\s+Tech|Caldwell|Caldwell\s+College|California|California\s+Baptist|California\s+Baptist\s+University|California\s+College\s+of\s+Arts\s+and\s+Crafts|California\s+Institute\s+of\s+Technology|California\s+Institute\s+of\s+the\s+Arts|California\s+Lutheran|California\s+Lutheran\s+University|California\s+State\s+Polytechnic\s+University--Pomona|California\s+State\s+Polytechnic\s+University\s*[-:,]+\s*Pomona|California\s+State\s+University--Bakersfield|California\s+State\s+University--Chico|California\s+State\s+University--Dominguez\s+Hills|California\s+State\s+University--Fresno|California\s+State\s+University--Fullerton|California\s+State\s+University--Hayward|California\s+State\s+University--Long\s+Beach|California\s+State\s+University--Los\s+Angeles|California\s+State\s+University--Northridge|California\s+State\s+University--Sacramento|California\s+State\s+University--San\s+Bernardino|California\s+State\s+University--San\s+Marcos|California\s+State\s+University--Stanislaus|California\s+State\s+University\s*[-:,]+\s*Bakersfield|California\s+State\s+University\s*[-:,]+\s*Chico|California\s+State\s+University\s*[-:,]+\s*Dominguez\s+Hills|California\s+State\s+University\s*[-:,]+\s*Fresno|California\s+State\s+University\s*[-:,]+\s*Fullerton|California\s+State\s+University\s*[-:,]+\s*Hayward|California\s+State\s+University\s*[-:,]+\s*Long\s+Beach|California\s+State\s+University\s*[-:,]+\s*Los\s+Angeles|California\s+State\s+University\s*[-:,]+\s*Northridge|California\s+State\s+University\s*[-:,]+\s*Sacramento|California\s+State\s+University\s*[-:,]+\s*San\s+Bernardino|California\s+State\s+University\s*[-:,]+\s*San\s+Marcos|California\s+State\s+University\s*[-:,]+\s*Stanislaus|California\s+University\s+of\s+Pennsylvania|Caltech|Calumet|Calumet\s+College\s+of\s+St\.?\s+Joseph|Calvin|Calvin\s+College|Cameron|Cameron\s+University|Campbell|Campbell\s+University|Campbellsville|Campbellsville\s+University|Canisius|Canisius\s+College|Capital|Capital\s+University|Capitol|Capitol\s+College|Cardinal\s+Stritch|Cardinal\s+Stritch\s+University|Carleton|Carleton\s+College|Carlow|Carlow\s+College|Carnegie\s+Mellon|Carnegie\s+Mellon\s+University|Carroll|Carroll\s+College|Carson-Newman|Carson-Newman\s+College|Carthage|Carthage\s+College|Case\s+Western\s+Reserve|Case\s+Western\s+Reserve\s+University|Castleton\s+State|Castleton\s+State\s+College|Catawba|Catawba\s+College|Catholic|Catholic\s+University\s+of\s+America|Cazenovia|Cazenovia\s+College|Cedar\s+Crest|Cedar\s+Crest\s+College|Cedarville|Cedarville\s+University|Centenary|Centenary\s+College|Centenary\s+College\s+of\s+Louisiana|Center\s+for\s+Creative\s+Studies|Central|Central\s+Christian|Central\s+Christian\s+College|Central\s+College|Central\s+Connecticut\s+State|Central\s+Connecticut\s+State\s+University|Central\s+Methodist|Central\s+Methodist\s+College|Central\s+Michigan|Central\s+Michigan\s+University|Central\s+Missouri\s+State|Central\s+Missouri\s+State\s+University|Central\s+State|Central\s+State\s+University|Central\s+Washington|Central\s+Washington\s+University|Centre|Centre\s+College|Chadron\s+State|Chadron\s+State\s+College|Chaminade|Chaminade\s+University\s+of\s+Honolulu|Champlain|Champlain\s+College|Chapman|Chapman\s+University|Charleston\s+Southern|Charleston\s+Southern\s+University|Chatham|Chatham\s+College|Chestnut\s+Hill|Chestnut\s+Hill\s+College|Cheyney|Cheyney\s+University\s+of\s+Pennsylvania|Chicago\s+State|Chicago\s+State\s+University|Chowan|Chowan\s+College|Christendom|Christendom\s+College|Christian\s+Brothers|Christian\s+Brothers\s+University|Christian\s+Heritage|Christian\s+Heritage\s+College|Christopher\s+Newport|Christopher\s+Newport\s+University|City|City\s+University|Claflin|Claflin\s+University|Claremont\s+McKenna|Claremont\s+McKenna\s+College|Clarion|Clarion\s+University\s+of\s+Pennsylvania|Clark|Clark\s+Atlanta|Clark\s+Atlanta\s+University|Clark\s+University|Clarke|Clarke\s+College|Clarkson|Clarkson\s+University|Clayton\s+College\s+and\s+State|Clayton\s+College\s+and\s+State\s+University|Clearwater\s+Christian|Clearwater\s+Christian\s+College|Cleary|Cleary\s+University|Clemson|Clemson\s+University|Cleveland\s+Institute\s+of\s+Art|Cleveland\s+Institute\s+of\s+Music|Cleveland\s+State|Cleveland\s+State\s+University|Coastal\s+Carolina|Coastal\s+Carolina\s+University|Coe|Coe\s+College|Coker|Coker\s+College|Colby|Colby-Sawyer|Colby-Sawyer\s+College|Colby\s+College|Colgate|Colgate\s+University|College\s+Misericordia|College\s+for\s+Lifelong\s+Learning|College\s+of\s+Aeronautics|College\s+of\s+Charleston|College\s+of\s+Mount\s+St\.?\s+Joseph|College\s+of\s+Mount\s+St\.?\s+Vincent|College\s+of\s+New\s+Jersey|College\s+of\s+New\s+Rochelle|College\s+of\s+Notre\s+Dame\s+of\s+Maryland|College\s+of\s+Santa\s+Fe|College\s+of\s+St\.?\s+Benedict|College\s+of\s+St\.?\s+Catherine|College\s+of\s+St\.?\s+Elizabeth|College\s+of\s+St\.?\s+Joseph|College\s+of\s+St\.?\s+Mary|College\s+of\s+St\.?\s+Rose|College\s+of\s+St\.?\s+Scholastica|College\s+of\s+Visual\s+Arts|College\s+of\s+William\s+and\s+Mary|College\s+of\s+Wooster|College\s+of\s+the\s+Atlantic|College\s+of\s+the\s+Holy\s+Cross|College\s+of\s+the\s+Ozarks|College\s+of\s+the\s+Southwest|Colorado|Colorado\s+Christian|Colorado\s+Christian\s+University|Colorado\s+College|Colorado\s+School\s+of\s+Mines|Colorado\s+State|Colorado\s+State\s+University|Columbia|Columbia\s+College|Columbia\s+Union|Columbia\s+Union\s+College|Columbia\s+University|Columbus|Columbus\s+College\s+of\s+Art\s+and\s+Design|Columbus\s+State|Columbus\s+State\s+University|Concord|Concord\s+College|Concordia|Concordia\s+College|Concordia\s+College--Moorhead|Concordia\s+College\s*[-:,]+\s*Moorhead|Concordia\s+University|Concordia\s+University--Austin|Concordia\s+University--River\s+Forest|Concordia\s+University--St\.?\s+Paul|Concordia\s+University\s*[-:,]+\s*Austin|Concordia\s+University\s*[-:,]+\s*River\s+Forest|Concordia\s+University\s*[-:,]+\s*St\.?\s+Paul|Concordia\s+University\s+Wisconsin|Connecticut|Connecticut\s+College|Converse|Converse\s+College|Cooper\s+Union|Coppin\s+State|Coppin\s+State\s+College|Corcoran|Corcoran\s+College\s+of\s+Art\s+and\s+Design|Cornell|Cornell\s+College|Cornell\s+University|Cornerstone|Cornerstone\s+University|Cornish|Cornish\s+College\s+of\s+the\s+Arts|Covenant|Covenant\s+College|Creighton|Creighton\s+University|Crichton|Crichton\s+College|Crown|Crown\s+College|Culver-Stockton|Culver-Stockton\s+College|Cumberland|Cumberland\s+College|Cumberland\s+University|Curry|Curry\s+College|Curtis\s+Institute\s+of\s+Music|Daemen|Daemen\s+College|Dakota\s+State|Dakota\s+State\s+University|Dakota\s+Wesleyan|Dakota\s+Wesleyan\s+University|Dallas\s+Baptist|Dallas\s+Baptist\s+University|Dana|Dana\s+College|Daniel\s+Webster|Daniel\s+Webster\s+College|Dartmouth|Dartmouth\s+College|Davenport|Davenport\s+University|David\s+Lipscomb|David\s+Lipscomb\s+University|Davidson|Davidson\s+College|Davis\s+and\s+Elkins|Davis\s+and\s+Elkins\s+College|DePaul|DePaul\s+University|DePauw|DePauw\s+University|DeSales|DeSales\s+University|Defiance|Defiance\s+College|Delaware\s+State|Delaware\s+State\s+University|Delaware\s+Valley|Delaware\s+Valley\s+College|Delta\s+State|Delta\s+State\s+University|Denison|Denison\s+University|Dickinson|Dickinson\s+College|Dickinson\s+State|Dickinson\s+State\s+University|Dillard|Dillard\s+University|Doane|Doane\s+College|Dominican|Dominican\s+College\s+of\s+Blauvelt|Dominican\s+University|Dominican\s+University\s+of\s+California|Dordt|Dordt\s+College|Dowling|Dowling\s+College|Drake|Drake\s+University|Drew|Drew\s+University|Drexel|Drexel\s+University|Drury|Drury\s+University|Duke|Duke\s+University|Duquesne|Duquesne\s+University|Earlham|Earlham\s+College|East-West|East-West\s+University|East\s+Carolina|East\s+Carolina\s+University|East\s+Central|East\s+Central\s+University|East\s+Stroudsburg|East\s+Stroudsburg\s+University\s+of\s+Pennsylvania|East\s+Tennessee\s+State|East\s+Tennessee\s+State\s+University|East\s+Texas\s+Baptist|East\s+Texas\s+Baptist\s+University|Eastern|Eastern\s+Connecticut\s+State|Eastern\s+Connecticut\s+State\s+University|Eastern\s+Illinois|Eastern\s+Illinois\s+University|Eastern\s+Kentucky|Eastern\s+Kentucky\s+University|Eastern\s+Mennonite|Eastern\s+Mennonite\s+University|Eastern\s+Michigan|Eastern\s+Michigan\s+University|Eastern\s+Nazarene|Eastern\s+Nazarene\s+College|Eastern\s+New\s+Mexico|Eastern\s+New\s+Mexico\s+University|Eastern\s+Oregon|Eastern\s+Oregon\s+University|Eastern\s+University|Eastern\s+Washington|Eastern\s+Washington\s+University|Eckerd|Eckerd\s+College|Edgewood|Edgewood\s+College|Edinboro|Edinboro\s+University\s+of\s+Pennsylvania|Edward\s+Waters|Edward\s+Waters\s+College|Elizabeth\s+City\s+State|Elizabeth\s+City\s+State\s+University|Elizabethtown|Elizabethtown\s+College|Elmhurst|Elmhurst\s+College|Elmira|Elmira\s+College|Elms|Elms\s+College\s+(College\s+of\s+Our\s+Lady\s+of\s+the\s+Elms)|Elon|Elon\s+University|Embry\s+Riddle\s+Aeronautical|Embry\s+Riddle\s+Aeronautical\s+University|Emerson|Emerson\s+College|Emmanuel|Emmanuel\s+College|Emory|Emory\s+University|Emory\s+and\s+Henry|Emory\s+and\s+Henry\s+College|Emporia\s+State|Emporia\s+State\s+University|Endicott|Endicott\s+College|Erskine|Erskine\s+College|Eureka|Eureka\s+College|Evangel|Evangel\s+University|Evergreen\s+State|Evergreen\s+State\s+College|Excelsior|Excelsior\s+College|Fairfield|Fairfield\s+University|Fairleigh\s+Dickinson|Fairleigh\s+Dickinson\s+University|Fairmont\s+State|Fairmont\s+State\s+College|Fashion\s+Institute\s+of\s+Technology|Faulkner|Faulkner\s+University|Fayetteville\s+State|Fayetteville\s+State\s+University|Felician|Felician\s+College|Ferris\s+State|Ferris\s+State\s+University|Ferrum|Ferrum\s+College|Fisk|Fisk\s+University|Fitchburg\s+State|Fitchburg\s+State\s+College|Flagler|Flagler\s+College|Florida\s+A&M|Florida\s+A&M\s+University|Florida\s+Atlantic|Florida\s+Atlantic\s+University|Florida\s+Gulf\s+Coast|Florida\s+Gulf\s+Coast\s+University|Florida\s+Institute\s+of\s+Technology|Florida\s+International|Florida\s+International\s+University|Florida\s+Memorial|Florida\s+Memorial\s+College|Florida\s+Southern|Florida\s+Southern\s+College|Florida\s+State|Florida\s+State\s+University|Fontbonne|Fontbonne\s+University|Fordham|Fordham\s+University|Fort\s+Hays\s+State|Fort\s+Hays\s+State\s+University|Fort\s+Lewis|Fort\s+Lewis\s+College|Fort\s+Valley\s+State|Fort\s+Valley\s+State\s+University|Framingham\s+State|Framingham\s+State\s+College|Francis\s+Marion|Francis\s+Marion\s+University|Franciscan|Franciscan\s+University\s+of\s+Steubenville|Franklin|Franklin\s+College|Franklin\s+Pierce|Franklin\s+Pierce\s+College|Franklin\s+University|Franklin\s+and\s+Marshall|Franklin\s+and\s+Marshall\s+College|Freed-Hardeman|Freed-Hardeman\s+University|Fresno\s+Pacific|Fresno\s+Pacific\s+University|Friends|Friends\s+University|Frostburg\s+State|Frostburg\s+State\s+University|Furman|Furman\s+University|Gallaudet|Gallaudet\s+University|Gannon|Gannon\s+University|Gardner-Webb|Gardner-Webb\s+University|Geneva|Geneva\s+College|George\s+Fox|George\s+Fox\s+University|George\s+Mason|George\s+Mason\s+University|George\s+Washington|George\s+Washington\s+University|Georgetown|Georgetown\s+College|Georgetown\s+University|Georgia\s+College\s+and\s+State|Georgia\s+College\s+and\s+State\s+University|Georgia\s+Institute\s+of\s+Technology|Georgia\s+Southern|Georgia\s+Southern\s+University|Georgia\s+Southwestern\s+State|Georgia\s+Southwestern\s+State\s+University|Georgia\s+State|Georgia\s+State\s+University|Georgia\s+Tech|Georgian\s+Court|Georgian\s+Court\s+College|Gettysburg|Gettysburg\s+College|Glenville\s+State|Glenville\s+State\s+College|Goddard|Goddard\s+College|Golden\s+Gate|Golden\s+Gate\s+University|Goldey\s+Beacom|Goldey\s+Beacom\s+College|Gonzaga|Gonzaga\s+University|Gordon|Gordon\s+College|Goshen|Goshen\s+College|Goucher|Goucher\s+College|Grace|Grace\s+College\s+and\s+Seminary|Grace\s+University|Graceland|Graceland\s+University|Grambling\s+State|Grambling\s+State\s+University|Grand\s+Canyon|Grand\s+Canyon\s+University|Grand\s+Valley\s+State|Grand\s+Valley\s+State\s+University|Grand\s+View|Grand\s+View\s+College|Gratz|Gratz\s+College|Green\s+Mountain|Green\s+Mountain\s+College|Greensboro|Greensboro\s+College|Greenville|Greenville\s+College|Grinnell|Grinnell\s+College|Grove\s+City|Grove\s+City\s+College|Guilford|Guilford\s+College|Gustavus\s+Adolphus|Gustavus\s+Adolphus\s+College|Gwynedd-Mercy|Gwynedd-Mercy\s+College|Hamilton|Hamilton\s+College|Hamline|Hamline\s+University|Hampden-Sydney|Hampden-Sydney\s+College|Hampshire|Hampshire\s+College|Hampton|Hampton\s+University|Hannibal-LaGrange|Hannibal-LaGrange\s+College|Hanover|Hanover\s+College|Hardin-Simmons|Hardin-Simmons\s+University|Harding|Harding\s+University|Hartwick|Hartwick\s+College|Harvard|Harvard\s+University|Harvey\s+Mudd|Harvey\s+Mudd\s+College|Hastings|Hastings\s+College|Haverford|Haverford\s+College|Hawaii\s+Pacific|Hawaii\s+Pacific\s+University|Heidelberg|Heidelberg\s+College|Henderson\s+State|Henderson\s+State\s+University|Hendrix|Hendrix\s+College|Henry\s+Cogswell|Henry\s+Cogswell\s+College|Heritage|Heritage\s+College|High\s+Point|High\s+Point\s+University|Hilbert|Hilbert\s+College|Hillsdale|Hillsdale\s+College|Hiram|Hiram\s+College|Hobart\s+and\s+William\s+Smith|Hobart\s+and\s+William\s+Smith\s+Colleges|Hofstra|Hofstra\s+University|Hollins|Hollins\s+University|Holy\s+Family|Holy\s+Family\s+College|Holy\s+Names|Holy\s+Names\s+College|Hood|Hood\s+College|Hope|Hope\s+College|Hope\s+International|Hope\s+International\s+University|Houghton|Houghton\s+College|Houston\s+Baptist|Houston\s+Baptist\s+University|Howard|Howard\s+Payne|Howard\s+Payne\s+University|Howard\s+University|Humboldt\s+State|Humboldt\s+State\s+University|Humphreys|Humphreys\s+College|Huntingdon|Huntingdon\s+College|Huntington|Huntington\s+College|Husson|Husson\s+College|Huston-Tillotson|Huston-Tillotson\s+College|Idaho\s+State|Idaho\s+State\s+University|Illinois|Illinois\s+College|Illinois\s+Institute\s+of\s+Technology|Illinois\s+State|Illinois\s+State\s+University|Illinois\s+Wesleyan|Illinois\s+Wesleyan\s+University|Immaculata|Immaculata\s+College|Indiana|Indiana\s+Institute\s+of\s+Technology|Indiana\s+State|Indiana\s+State\s+University|Indiana\s+University--Bloomington|Indiana\s+University--Kokomo|Indiana\s+University--South\s+Bend|Indiana\s+University-Purdue\s+University--Fort\s+Wayne|Indiana\s+University-Purdue\s+University--Indianapolis|Indiana\s+University-Purdue\s+University\s*[-:,]+\s*Fort\s+Wayne|Indiana\s+University-Purdue\s+University\s*[-:,]+\s*Indianapolis|Indiana\s+University\s*[-:,]+\s*Bloomington|Indiana\s+University\s*[-:,]+\s*Kokomo|Indiana\s+University\s*[-:,]+\s*South\s+Bend|Indiana\s+University\s+East|Indiana\s+University\s+Northwest|Indiana\s+University\s+Southeast|Indiana\s+University\s+of\s+Pennsylvania|Indiana\s+Wesleyan|Indiana\s+Wesleyan\s+University|International|International\s+College|Iona|Iona\s+College|Iowa\s+State|Iowa\s+State\s+University|Iowa\s+Wesleyan|Iowa\s+Wesleyan\s+College|Ithaca|Ithaca\s+College|Jackson\s+State|Jackson\s+State\s+University|Jacksonville|Jacksonville\s+State|Jacksonville\s+State\s+University|Jacksonville\s+University|James\s+Madison|James\s+Madison\s+University|Jamestown|Jamestown\s+College|Jarvis\s+Christian|Jarvis\s+Christian\s+College|John\s+Brown|John\s+Brown\s+University|John\s+Carroll|John\s+Carroll\s+University|John\s+F\.?\s+Kennedy|John\s+F\.?\s+Kennedy\s+University|Johns\s+Hopkins|Johns\s+Hopkins\s+University|Johnson\s+C\.?\s+Smith|Johnson\s+C\.?\s+Smith\s+University|Johnson\s+State|Johnson\s+State\s+College|Johnson\s+and\s+Wales|Johnson\s+and\s+Wales\s+University|Judson|Judson\s+College|Juilliard|Juilliard\s+School|Juniata|Juniata\s+College|Kalamazoo|Kalamazoo\s+College|Kansas\s+City\s+Art\s+Institute|Kansas\s+State|Kansas\s+State\s+University|Kansas\s+Wesleyan|Kansas\s+Wesleyan\s+University|Kean|Kean\s+University|Keene\s+State|Keene\s+State\s+College|Kendall|Kendall\s+College|Kennesaw\s+State|Kennesaw\s+State\s+University|Kent\s+State|Kent\s+State\s+University|Kentucky\s+Christian|Kentucky\s+Christian\s+College|Kentucky\s+State|Kentucky\s+State\s+University|Kentucky\s+Wesleyan|Kentucky\s+Wesleyan\s+College|Kenyon|Kenyon\s+College|Kettering|Kettering\s+University|Keuka|Keuka\s+College|King|King's|King's\s+College|King\s+College|Knox|Knox\s+College|Kutztown|Kutztown\s+University\s+of\s+Pennsylvania|LaGrange|LaGrange\s+College|La\s+Roche|La\s+Roche\s+College|La\s+Salle|La\s+Salle\s+University|La\s+Sierra|La\s+Sierra\s+University|Lafayette|Lafayette\s+College|Lake\s+Erie|Lake\s+Erie\s+College|Lake\s+Forest|Lake\s+Forest\s+College|Lake\s+Superior\s+State|Lake\s+Superior\s+State\s+University|Lakeland|Lakeland\s+College|Lamar|Lamar\s+University|Lambuth|Lambuth\s+University|Lander|Lander\s+University|Lane|Lane\s+College|Langston|Langston\s+University|Lasell|Lasell\s+College|Lawrence|Lawrence\s+Technological|Lawrence\s+Technological\s+University|Lawrence\s+University|LeMoyne-Owen|LeMoyne-Owen\s+College|LeTourneau|LeTourneau\s+University|Le\s+Moyne|Le\s+Moyne\s+College|Lebanon\s+Valley|Lebanon\s+Valley\s+College|Lee|Lee\s+University|Lees-McRae|Lees-McRae\s+College|Lehigh|Lehigh\s+University|Lenoir-Rhyne|Lenoir-Rhyne\s+College|Lesley|Lesley\s+University|Lewis|Lewis-Clark\s+State|Lewis-Clark\s+State\s+College|Lewis\s+University|Lewis\s+and\s+Clark|Lewis\s+and\s+Clark\s+College|Liberty|Liberty\s+University|Limestone|Limestone\s+College|Lincoln|Lincoln\s+Memorial|Lincoln\s+Memorial\s+University|Lincoln\s+University|Lindenwood|Lindenwood\s+University|Lindsey\s+Wilson|Lindsey\s+Wilson\s+College|Linfield|Linfield\s+College|Livingstone|Livingstone\s+College|Lock\s+Haven|Lock\s+Haven\s+University\s+of\s+Pennsylvania|Long\s+Island\s+University--Brooklyn|Long\s+Island\s+University--C\.?W\.?\s+Post\s+Campus|Long\s+Island\s+University--Southampton\s+College|Long\s+Island\s+University\s*[-:,]+\s*Brooklyn|Long\s+Island\s+University\s*[-:,]+\s*C\.?W\.?\s+Post\s+Campus|Long\s+Island\s+University\s*[-:,]+\s*Southampton\s+College|Longwood|Longwood\s+University|Longy\s+School\s+of\s+Music|Loras|Loras\s+College|Louisiana|Louisiana\s+College|Louisiana\s+State\s+University--Baton\s+Rouge|Louisiana\s+State\s+University--Shreveport|Louisiana\s+State\s+University\s*[-:,]+\s*Baton\s+Rouge|Louisiana\s+State\s+University\s*[-:,]+\s*Shreveport|Louisiana\s+Tech|Louisiana\s+Tech\s+University|Lourdes|Lourdes\s+College|Loyola|Loyola\s+College\s+in\s+Maryland|Loyola\s+Marymount|Loyola\s+Marymount\s+University|Loyola\s+University\s+Chicago|Loyola\s+University\s+New\s+Orleans|Lubbock\s+Christian|Lubbock\s+Christian\s+University|Luther|Luther\s+College|Lycoming|Lycoming\s+College|Lynchburg|Lynchburg\s+College|Lyndon\s+State|Lyndon\s+State\s+College|Lynn|Lynn\s+University|Lyon|Lyon\s+College|MCP\s+Hahnemann|MCP\s+Hahnemann\s+University|MIT|MacMurray|MacMurray\s+College|Macalester|Macalester\s+College|Madonna|Madonna\s+University|Maharishi|Maharishi\s+University\s+of\s+Management|Maine|Maine\s+College\s+of\s+Art|Malone|Malone\s+College|Manchester|Manchester\s+College|Manhattan|Manhattan\s+College|Manhattan\s+School\s+of\s+Music|Manhattanville|Manhattanville\s+College|Mansfield|Mansfield\s+University\s+of\s+Pennsylvania|Marian|Marian\s+College|Marian\s+College\s+of\s+Fond\s+du\s+Lac|Marietta|Marietta\s+College|Marist|Marist\s+College|Marlboro|Marlboro\s+College|Marquette|Marquette\s+University|Mars\s+Hill|Mars\s+Hill\s+College|Marshall|Marshall\s+University|Martin|Martin\s+Methodist|Martin\s+Methodist\s+College|Martin\s+University|Mary\s+Baldwin|Mary\s+Baldwin\s+College|Mary\s+Washington|Mary\s+Washington\s+College|Marygrove|Marygrove\s+College|Maryland\s+Institute|Maryland\s+Institute\s+College\s+of\s+Art|Marylhurst|Marylhurst\s+University|Marymount|Marymount\s+College--Tarrytown|Marymount\s+College\s*[-:,]+\s*Tarrytown|Marymount\s+Manhattan|Marymount\s+Manhattan\s+College|Marymount\s+University|Maryville|Maryville\s+College|Maryville\s+University\s+of\s+St\.?\s+Louis|Marywood|Marywood\s+University|Massachusetts|Massachusetts\s+College\s+of\s+Art|Massachusetts\s+College\s+of\s+Liberal\s+Arts|Massachusetts\s+Inst\.?\s+of\s+Technology|Massachusetts\s+Institute\s+of\s+Technology|Master's|Master's\s+College\s+and\s+Seminary|Mayville\s+State|Mayville\s+State\s+University|McDaniel|McDaniel\s+College|McKendree|McKendree\s+College|McMurry|McMurry\s+University|McNeese\s+State|McNeese\s+State\s+University|McPherson|McPherson\s+College|Medaille|Medaille\s+College|Memphis|Memphis\s+College\s+of\s+Art|Menlo|Menlo\s+College|Mercer|Mercer\s+University|Mercy|Mercy\s+College|Mercyhurst|Mercyhurst\s+College|Meredith|Meredith\s+College|Merrimack|Merrimack\s+College|Mesa\s+State|Mesa\s+State\s+College|Messiah|Messiah\s+College|Methodist|Methodist\s+College|Metropolitan\s+State|Metropolitan\s+State\s+College\s+of\s+Denver|Metropolitan\s+State\s+University|Miami\s+University--Oxford|Miami\s+University\s*[-:,]+\s*Oxford|Michigan\s+State|Michigan\s+State\s+University|Michigan\s+Technological|Michigan\s+Technological\s+University|Mid-Continent|Mid-Continent\s+College|MidAmerica\s+Nazarene|MidAmerica\s+Nazarene\s+University|Middle\s+Tennessee\s+State|Middle\s+Tennessee\s+State\s+University|Middlebury|Middlebury\s+College|Midland\s+Lutheran|Midland\s+Lutheran\s+College|Midway|Midway\s+College|Midwestern\s+State|Midwestern\s+State\s+University|Miles|Miles\s+College|Millersville|Millersville\s+University\s+of\s+Pennsylvania|Milligan|Milligan\s+College|Millikin|Millikin\s+University|Mills|Mills\s+College|Millsaps|Millsaps\s+College|Milwaukee\s+Institute\s+of\s+Art\s+and\s+Design|Milwaukee\s+School\s+of\s+Engineering|Minneapolis|Minneapolis\s+College\s+of\s+Art\s+and\s+Design|Minnesota\s+State\s+University--Mankato|Minnesota\s+State\s+University--Moorhead|Minnesota\s+State\s+University\s*[-:,]+\s*Mankato|Minnesota\s+State\s+University\s*[-:,]+\s*Moorhead|Minot\s+State|Minot\s+State\s+University|Mississippi|Mississippi\s+College|Mississippi\s+State|Mississippi\s+State\s+University|Mississippi\s+University\s+for\s+Women|Mississippi\s+Valley\s+State|Mississippi\s+Valley\s+State\s+University|Missouri\s+Baptist|Missouri\s+Baptist\s+College|Missouri\s+Southern\s+State|Missouri\s+Southern\s+State\s+College|Missouri\s+Valley|Missouri\s+Valley\s+College|Missouri\s+Western\s+State|Missouri\s+Western\s+State\s+College|Molloy|Molloy\s+College|Monmouth|Monmouth\s+College|Monmouth\s+University|Montana\s+State\s+University--Billings|Montana\s+State\s+University--Bozeman|Montana\s+State\s+University--Northern|Montana\s+State\s+University\s*[-:,]+\s*Billings|Montana\s+State\s+University\s*[-:,]+\s*Bozeman|Montana\s+State\s+University\s*[-:,]+\s*Northern|Montana\s+Tech\s+of\s+the|Montana\s+Tech\s+of\s+the\s+University\s+of\s+Montana|Montclair\s+State|Montclair\s+State\s+University|Montreat|Montreat\s+College|Montserrat|Montserrat\s+College\s+of\s+Art|Moore|Moore\s+College\s+of\s+Art\s+and\s+Design|Moravian|Moravian\s+College|Morehead\s+State|Morehead\s+State\s+University|Morehouse|Morehouse\s+College|Morgan\s+State|Morgan\s+State\s+University|Morningside|Morningside\s+College|Morris|Morris\s+Brown|Morris\s+Brown\s+College|Morris\s+College|Mount\s+Aloysius|Mount\s+Aloysius\s+College|Mount\s+Holyoke|Mount\s+Holyoke\s+College|Mount\s+Ida|Mount\s+Ida\s+College|Mount\s+Marty|Mount\s+Marty\s+College|Mount\s+Mary|Mount\s+Mary\s+College|Mount\s+Mercy|Mount\s+Mercy\s+College|Mount\s+Olive|Mount\s+Olive\s+College|Mount\s+St\.?\s+Clare|Mount\s+St\.?\s+Clare\s+College|Mount\s+St\.?\s+Mary|Mount\s+St\.?\s+Mary's|Mount\s+St\.?\s+Mary's\s+College|Mount\s+St\.?\s+Mary\s+College|Mount\s+Union|Mount\s+Union\s+College|Mount\s+Vernon\s+Nazarene|Mount\s+Vernon\s+Nazarene\s+University|Mountain\s+State|Mountain\s+State\s+University|Muhlenberg|Muhlenberg\s+College|Murray\s+State|Murray\s+State\s+University|Muskingum|Muskingum\s+College|Myers|Myers\s+University|NYU|National|National-Louis|National-Louis\s+University|National\s+University|Nazareth|Nazareth\s+College\s+of\s+Rochester|Nebraska\s+Wesleyan|Nebraska\s+Wesleyan\s+University|Neumann|Neumann\s+College|New|New\s+College\s+of\s+California|New\s+England|New\s+England\s+College|New\s+England\s+Conservatory\s+of\s+Music|New\s+Jersey\s+City|New\s+Jersey\s+City\s+University|New\s+Jersey\s+Institute\s+of\s+Technology|New\s+Mexico\s+Highlands|New\s+Mexico\s+Highlands\s+University|New\s+Mexico\s+Institute\s+of\s+Mining\s+and\s+Technology|New\s+Mexico\s+State|New\s+Mexico\s+State\s+University|New\s+School|New\s+School\s+University|New\s+York|New\s+York\s+Institute\s+of\s+Technology|New\s+York\s+University|Newberry|Newberry\s+College|Newbury|Newbury\s+College|Newman|Newman\s+University|Niagara|Niagara\s+University|Nicholls\s+State|Nicholls\s+State\s+University|Nichols|Nichols\s+College|Norfolk\s+State|Norfolk\s+State\s+University|North\s+Carolina\s+A&T\s+State|North\s+Carolina\s+A&T\s+State\s+University|North\s+Carolina\s+Central|North\s+Carolina\s+Central\s+University|North\s+Carolina\s+School\s+of\s+the\s+Arts|North\s+Carolina\s+State\s+University--Raleigh|North\s+Carolina\s+State\s+University\s*[-:,]+\s*Raleigh|North\s+Carolina\s+Wesleyan|North\s+Carolina\s+Wesleyan\s+College|North\s+Central|North\s+Central\s+College|North\s+Dakota\s+State|North\s+Dakota\s+State\s+University|North\s+Georgia\s+College\s+and\s+State|North\s+Georgia\s+College\s+and\s+State\s+University|North\s+Greenville|North\s+Greenville\s+College|North\s+Park|North\s+Park\s+University|Northeastern|Northeastern\s+Illinois|Northeastern\s+Illinois\s+University|Northeastern\s+State|Northeastern\s+State\s+University|Northeastern\s+University|Northern\s+Arizona|Northern\s+Arizona\s+University|Northern\s+Illinois|Northern\s+Illinois\s+University|Northern\s+Kentucky|Northern\s+Kentucky\s+University|Northern\s+Michigan|Northern\s+Michigan\s+University|Northern\s+State|Northern\s+State\s+University|Northland|Northland\s+College|Northwest|Northwest\s+Christian|Northwest\s+Christian\s+College|Northwest\s+College|Northwest\s+Missouri\s+State|Northwest\s+Missouri\s+State\s+University|Northwest\s+Nazarene|Northwest\s+Nazarene\s+University|Northwestern|Northwestern\s+College|Northwestern\s+Oklahoma\s+State|Northwestern\s+Oklahoma\s+State\s+University|Northwestern\s+State|Northwestern\s+State\s+University\s+of\s+Louisiana|Northwestern\s+University|Northwood|Northwood\s+University|Norwich|Norwich\s+University|Notre\s+Dame|Notre\s+Dame\s+College\s+of\s+Ohio|Notre\s+Dame\s+de\s+Namur|Notre\s+Dame\s+de\s+Namur\s+University|Nova\s+Southeastern|Nova\s+Southeastern\s+University|Nyack|Nyack\s+College|Oakland|Oakland\s+City|Oakland\s+City\s+University|Oakland\s+University|Oakwood|Oakwood\s+College|Oberlin|Oberlin\s+College|Occidental|Occidental\s+College|Oglethorpe|Oglethorpe\s+University|Ohio|Ohio\s+Dominican|Ohio\s+Dominican\s+University|Ohio\s+Northern|Ohio\s+Northern\s+University|Ohio\s+State\s+University--Columbus|Ohio\s+State\s+University\s*[-:,]+\s*Columbus|Ohio\s+University|Ohio\s+Valley|Ohio\s+Valley\s+College|Ohio\s+Wesleyan|Ohio\s+Wesleyan\s+University|Oklahoma\s+Baptist|Oklahoma\s+Baptist\s+University|Oklahoma\s+Christian|Oklahoma\s+Christian\s+University|Oklahoma\s+City|Oklahoma\s+City\s+University|Oklahoma\s+Panhandle\s+State|Oklahoma\s+Panhandle\s+State\s+University|Oklahoma\s+State|Oklahoma\s+State\s+University|Oklahoma\s+Wesleyan|Oklahoma\s+Wesleyan\s+University|Old\s+Dominion|Old\s+Dominion\s+University|Olivet|Olivet\s+College|Olivet\s+Nazarene|Olivet\s+Nazarene\s+University|Oral\s+Roberts|Oral\s+Roberts\s+University|Oregon\s+Institute\s+of\s+Technology|Oregon\s+State|Oregon\s+State\s+University|Otis|Otis\s+College\s+of\s+Art\s+and\s+Design|Ottawa|Ottawa\s+University|Otterbein|Otterbein\s+College|Ouachita\s+Baptist|Ouachita\s+Baptist\s+University|Our\s+Lady\s+of\s+Holy\s+Cross|Our\s+Lady\s+of\s+Holy\s+Cross\s+College|Our\s+Lady\s+of\s+the\s+Lake|Our\s+Lady\s+of\s+the\s+Lake\s+University|Pace|Pace\s+University|Pacific|Pacific\s+Lutheran|Pacific\s+Lutheran\s+University|Pacific\s+Northwest|Pacific\s+Northwest\s+College\s+of\s+Art|Pacific\s+Union|Pacific\s+Union\s+College|Pacific\s+University|Paine|Paine\s+College|Palm\s+Beach\s+Atlantic|Palm\s+Beach\s+Atlantic\s+University|Park|Park\s+University|Patten|Patten\s+College|Paul\s+Quinn|Paul\s+Quinn\s+College|Peace|Peace\s+College|Penn\s+State|Pennsylvania|Pennsylvania\s+College\s+of\s+Technology|Pennsylvania\s+State--Erie,\s+The\s+Behrend\s+College|Pennsylvania\s+State\s*[-:,]+\s*Erie,\s+The\s+Behrend\s+College|Pennsylvania\s+State\s+University|Pennsylvania\s+State\s+University--University\s+Park|Pennsylvania\s+State\s+University\s*[-:,]+\s*University\s+Park|Pepperdine|Pepperdine\s+University|Peru\s+State|Peru\s+State\s+College|Pfeiffer|Pfeiffer\s+University|Philadelphia|Philadelphia\s+University|Philander\s+Smith|Philander\s+Smith\s+College|Piedmont|Piedmont\s+College|Pikeville|Pikeville\s+College|Pine\s+Manor|Pine\s+Manor\s+College|Pittsburg\s+State|Pittsburg\s+State\s+University|Pitzer|Pitzer\s+College|Plymouth\s+State|Plymouth\s+State\s+College|Point\s+Loma\s+Nazarene|Point\s+Loma\s+Nazarene\s+University|Point\s+Park|Point\s+Park\s+College|Polytechnic|Polytechnic\s+University|Pomona|Pomona\s+College|Portland\s+State|Portland\s+State\s+University|Prairie\s+View\s+A&M|Prairie\s+View\s+A&M\s+University|Pratt\s+Institute|Presbyterian|Presbyterian\s+College|Prescott|Prescott\s+College|Princeton|Princeton\s+University|Principia|Principia\s+College|Providence|Providence\s+College|Purdue\s+University--Calumet|Purdue\s+University--North\s+Central|Purdue\s+University--West\s+Lafayette|Purdue\s+University\s*[-:,]+\s*Calumet|Purdue\s+University\s*[-:,]+\s*North\s+Central|Purdue\s+University\s*[-:,]+\s*West\s+Lafayette|Queens|Queens\s+University\s+of\s+Charlotte|Quincy|Quincy\s+University|Quinnipiac|Quinnipiac\s+University|RPI|Radford|Radford\s+University|Ramapo|Ramapo\s+College\s+of\s+New\s+Jersey|Randolph-Macon|Randolph-Macon\s+College|Randolph-Macon\s+Woman's|Randolph-Macon\s+Woman's\s+College|Reed|Reed\s+College|Regent|Regent\s+University|Regis|Regis\s+College|Regis\s+University|Reinhardt|Reinhardt\s+College|Rensselaer\s+Polytechnic\s+Institute|Rhode\s+Island|Rhode\s+Island\s+College|Rhode\s+Island\s+School\s+of\s+Design|Rhodes|Rhodes\s+College|Rice|Rice\s+University|Richard\s+Stockton|Richard\s+Stockton\s+College\s+of\s+New\s+Jersey|Rider|Rider\s+University|Ringling\s+School\s+of\s+Art\s+and\s+Design|Ripon|Ripon\s+College|Rivier|Rivier\s+College|Roanoke|Roanoke\s+College|Robert\s+Morris|Robert\s+Morris\s+College|Robert\s+Morris\s+University|Roberts\s+Wesleyan|Roberts\s+Wesleyan\s+College|Rochester|Rochester\s+College|Rochester\s+Institute\s+of\s+Technology|Rockford|Rockford\s+College|Rockhurst|Rockhurst\s+University|Rocky\s+Mountain|Rocky\s+Mountain\s+College|Roger\s+Williams|Roger\s+Williams\s+University|Rollins|Rollins\s+College|Roosevelt|Roosevelt\s+University|Rose-Hulman\s+Institute\s+of\s+Technology|Rosemont|Rosemont\s+College|Rowan|Rowan\s+University|Russell\s+Sage|Russell\s+Sage\s+College|Rust|Rust\s+College|Rutgers--Camden|Rutgers--New\s+Brunswick|Rutgers--Newark|Rutgers\s*[-:,]+\s*Camden|Rutgers\s*[-:,]+\s*New\s+Brunswick|Rutgers\s*[-:,]+\s*Newark|SUNY|SUNY--Albany|SUNY--Binghamton|SUNY--Empire\s+State\s+College|SUNY--Farmingdale|SUNY--Oswego|SUNY--Plattsburgh|SUNY--Purchase\s+College|SUNY--Stony\s+Brook|SUNY--University\s+at\s+Buffalo|SUNY\s*[-:,]+\s*Albany|SUNY\s*[-:,]+\s*Binghamton|SUNY\s*[-:,]+\s*Empire\s+State\s+College|SUNY\s*[-:,]+\s*Farmingdale|SUNY\s*[-:,]+\s*Oswego|SUNY\s*[-:,]+\s*Plattsburgh|SUNY\s*[-:,]+\s*Purchase\s+College|SUNY\s*[-:,]+\s*Stony\s+Brook|SUNY\s*[-:,]+\s*University\s+at\s+Buffalo|SUNY\s+College--Brockport|SUNY\s+College--Cortland|SUNY\s+College--Fredonia|SUNY\s+College--Old\s+Westbury|SUNY\s+College--Oneonta|SUNY\s+College--Potsdam|SUNY\s+College\s*[-:,]+\s*Brockport|SUNY\s+College\s*[-:,]+\s*Cortland|SUNY\s+College\s*[-:,]+\s*Fredonia|SUNY\s+College\s*[-:,]+\s*Old\s+Westbury|SUNY\s+College\s*[-:,]+\s*Oneonta|SUNY\s+College\s*[-:,]+\s*Potsdam|SUNY\s+College\s+Environmental\s+Science\s+and\s+Forestry|SUNY\s+College\s+of\s+A&T--Cobleskill|SUNY\s+College\s+of\s+A&T\s*[-:,]+\s*Cobleskill|SUNY\s+College\s+of\s+Arts\s+and\s+Sciences--Geneseo|SUNY\s+College\s+of\s+Arts\s+and\s+Sciences--New\s+Paltz|SUNY\s+College\s+of\s+Arts\s+and\s+Sciences\s*[-:,]+\s*Geneseo|SUNY\s+College\s+of\s+Arts\s+and\s+Sciences\s*[-:,]+\s*New\s+Paltz|Sacred\s+Heart|Sacred\s+Heart\s+University|Saginaw\s+Valley\s+State|Saginaw\s+Valley\s+State\s+University|Salem|Salem\s+College|Salem\s+International|Salem\s+International\s+University|Salem\s+State|Salem\s+State\s+College|Salisbury|Salisbury\s+University|Salve\s+Regina|Salve\s+Regina\s+University|Sam\s+Houston\s+State|Sam\s+Houston\s+State\s+University|Samford|Samford\s+University|San\s+Diego\s+State|San\s+Diego\s+State\s+University|San\s+Francisco\s+Art\s+Institute|San\s+Francisco\s+Conservatory\s+of\s+Music|San\s+Francisco\s+State|San\s+Francisco\s+State\s+University|San\s+Jose\s+State|San\s+Jose\s+State\s+University|Santa\s+Clara|Santa\s+Clara\s+University|Sarah\s+Lawrence|Sarah\s+Lawrence\s+College|Savannah|Savannah\s+College\s+of\s+Art\s+and\s+Design|Savannah\s+State|Savannah\s+State\s+University|School\s+of\s+the\s+Art\s+Institute\s+of\s+Chicago|Schreiner|Schreiner\s+University|Scripps|Scripps\s+College|Seattle|Seattle\s+Pacific|Seattle\s+Pacific\s+University|Seattle\s+University|Seton\s+Hall|Seton\s+Hall\s+University|Seton\s+Hill|Seton\s+Hill\s+College|Shaw|Shaw\s+University|Shawnee\s+State|Shawnee\s+State\s+University|Sheldon\s+Jackson|Sheldon\s+Jackson\s+College|Shenandoah|Shenandoah\s+University|Shepherd|Shepherd\s+College|Shimer|Shimer\s+College|Shippensburg|Shippensburg\s+University\s+of\s+Pennsylvania|Shorter|Shorter\s+College|Siena|Siena\s+College|Siena\s+Heights|Siena\s+Heights\s+University|Sierra\s+Nevada|Sierra\s+Nevada\s+College|Silver\s+Lake|Silver\s+Lake\s+College|Simmons|Simmons\s+College|Simon's\s+Rock|Simon's\s+Rock\s+College\s+of\s+Bard|Simpson|Simpson\s+College|Skidmore|Skidmore\s+College|Slippery\s+Rock|Slippery\s+Rock\s+University\s+of\s+Pennsylvania|Smith|Smith\s+College|Sonoma\s+State|Sonoma\s+State\s+University|South\s+Carolina\s+State|South\s+Carolina\s+State\s+University|South\s+Dakota\s+School\s+of\s+Mines\s+and\s+Technology|South\s+Dakota\s+State|South\s+Dakota\s+State\s+University|Southeast\s+Missouri\s+State|Southeast\s+Missouri\s+State\s+University|Southeastern|Southeastern\s+Louisiana|Southeastern\s+Louisiana\s+University|Southeastern\s+Oklahoma\s+State|Southeastern\s+Oklahoma\s+State\s+University|Southeastern\s+University|Southern\s+Adventist|Southern\s+Adventist\s+University|Southern\s+Arkansas|Southern\s+Arkansas\s+University|Southern\s+California\s+Institute\s+of\s+Architecture|Southern\s+Connecticut\s+State|Southern\s+Connecticut\s+State\s+University|Southern\s+Illinois\s+University--Carbondale|Southern\s+Illinois\s+University--Edwardsville|Southern\s+Illinois\s+University\s*[-:,]+\s*Carbondale|Southern\s+Illinois\s+University\s*[-:,]+\s*Edwardsville|Southern\s+Methodist|Southern\s+Methodist\s+University|Southern\s+Nazarene|Southern\s+Nazarene\s+University|Southern\s+New\s+Hampshire|Southern\s+New\s+Hampshire\s+University|Southern\s+Oregon|Southern\s+Oregon\s+University|Southern\s+Polytechnic\s+State|Southern\s+Polytechnic\s+State\s+University|Southern\s+University--New\s+Orleans|Southern\s+University\s*[-:,]+\s*New\s+Orleans|Southern\s+University\s+and\s+A&M|Southern\s+University\s+and\s+A&M\s+College|Southern\s+Utah|Southern\s+Utah\s+University|Southern\s+Vermont|Southern\s+Vermont\s+College|Southern\s+Wesleyan|Southern\s+Wesleyan\s+University|Southwest\s+Baptist|Southwest\s+Baptist\s+University|Southwest\s+Missouri\s+State|Southwest\s+Missouri\s+State\s+University|Southwest\s+State|Southwest\s+State\s+University|Southwest\s+Texas\s+State|Southwest\s+Texas\s+State\s+University|Southwestern|Southwestern\s+Adventist|Southwestern\s+Adventist\s+University|Southwestern\s+College|Southwestern\s+Oklahoma\s+State|Southwestern\s+Oklahoma\s+State\s+University|Southwestern\s+University|Spalding|Spalding\s+University|Spelman|Spelman\s+College|Spring\s+Arbor|Spring\s+Arbor\s+University|Spring\s+Hill|Spring\s+Hill\s+College|Springfield|Springfield\s+College|St\.?\s+Ambrose|St\.?\s+Ambrose\s+University|St\.?\s+Andrews\s+Presbyterian|St\.?\s+Andrews\s+Presbyterian\s+College|St\.?\s+Anselm|St\.?\s+Anselm\s+College|St\.?\s+Augustine's|St\.?\s+Augustine's\s+College|St\.?\s+Bonaventure|St\.?\s+Bonaventure\s+University|St\.?\s+Cloud\s+State|St\.?\s+Cloud\s+State\s+University|St\.?\s+Edward's|St\.?\s+Edward's\s+University|St\.?\s+Francis|St\.?\s+Francis\s+College|St\.?\s+Francis\s+University|St\.?\s+Gregory's|St\.?\s+Gregory's\s+University|St\.?\s+John's|St\.?\s+John's\s+College|St\.?\s+John's\s+University|St\.?\s+John\s+Fisher|St\.?\s+John\s+Fisher\s+College|St\.?\s+Joseph|St\.?\s+Joseph's|St\.?\s+Joseph's\s+College|St\.?\s+Joseph's\s+College,\s+New\s+York|St\.?\s+Joseph's\s+University|St\.?\s+Joseph\s+College|St\.?\s+Lawrence|St\.?\s+Lawrence\s+University|St\.?\s+Leo|St\.?\s+Leo\s+University|St\.?\s+Louis|St\.?\s+Louis\s+University|St\.?\s+Martin's|St\.?\s+Martin's\s+College|St\.?\s+Mary|St\.?\s+Mary's|St\.?\s+Mary's\s+College|St\.?\s+Mary's\s+College\s+of\s+California|St\.?\s+Mary's\s+College\s+of\s+Maryland|St\.?\s+Mary's\s+University\s+of\s+Minnesota|St\.?\s+Mary's\s+University\s+of\s+San\s+Antonio|St\.?\s+Mary-of-the-Woods|St\.?\s+Mary-of-the-Woods\s+College|St\.?\s+Mary\s+College|St\.?\s+Michael's|St\.?\s+Michael's\s+College|St\.?\s+Norbert|St\.?\s+Norbert\s+College|St\.?\s+Olaf|St\.?\s+Olaf\s+College|St\.?\s+Paul's|St\.?\s+Paul's\s+College|St\.?\s+Peter's|St\.?\s+Peter's\s+College|St\.?\s+Thomas|St\.?\s+Thomas\s+Aquinas|St\.?\s+Thomas\s+Aquinas\s+College|St\.?\s+Thomas\s+University|St\.?\s+Vincent|St\.?\s+Vincent\s+College|St\.?\s+Xavier|St\.?\s+Xavier\s+University|Stanford|Stanford\s+University|State|State\s+University\s+of\s+West\s+Georgia|Stephen\s+F\.?\s+Austin\s+State|Stephen\s+F\.?\s+Austin\s+State\s+University|Stephens|Stephens\s+College|Sterling|Sterling\s+College|Stetson|Stetson\s+University|Stevens\s+Institute\s+of\s+Technology|Stillman|Stillman\s+College|Stonehill|Stonehill\s+College|Suffolk|Suffolk\s+University|Sul\s+Ross\s+State|Sul\s+Ross\s+State\s+University|Susquehanna|Susquehanna\s+University|Swarthmore|Swarthmore\s+College|Sweet\s+Briar|Sweet\s+Briar\s+College|Syracuse|Syracuse\s+University|Tabor|Tabor\s+College|Talladega|Talladega\s+College|Tarleton\s+State|Tarleton\s+State\s+University|Taylor|Taylor\s+University|Teikyo\s+Post|Teikyo\s+Post\s+University|Temple|Temple\s+University|Tennessee\s+State|Tennessee\s+State\s+University|Tennessee\s+Technological|Tennessee\s+Technological\s+University|Tennessee\s+Wesleyan|Tennessee\s+Wesleyan\s+College|Texas|Texas\s+A&M\s+International|Texas\s+A&M\s+International\s+University|Texas\s+A&M\s+University--College\s+Station|Texas\s+A&M\s+University--Commerce|Texas\s+A&M\s+University--Corpus\s+Christi|Texas\s+A&M\s+University--Galveston|Texas\s+A&M\s+University--Kingsville|Texas\s+A&M\s+University\s*[-:,]+\s*College\s+Station|Texas\s+A&M\s+University\s*[-:,]+\s*Commerce|Texas\s+A&M\s+University\s*[-:,]+\s*Corpus\s+Christi|Texas\s+A&M\s+University\s*[-:,]+\s*Galveston|Texas\s+A&M\s+University\s*[-:,]+\s*Kingsville|Texas\s+Christian|Texas\s+Christian\s+University|Texas\s+College|Texas\s+Lutheran|Texas\s+Lutheran\s+University|Texas\s+Southern|Texas\s+Southern\s+University|Texas\s+Tech|Texas\s+Tech\s+University|Texas\s+Wesleyan|Texas\s+Wesleyan\s+University|Texas\s+Woman's|Texas\s+Woman's\s+University|The\s+Citadel|Thiel|Thiel\s+College|Thomas|Thomas\s+Aquinas|Thomas\s+Aquinas\s+College|Thomas\s+College|Thomas\s+Edison\s+State|Thomas\s+Edison\s+State\s+College|Thomas\s+More|Thomas\s+More\s+College|Thomas\s+University|Tiffin|Tiffin\s+University|Toccoa\s+Falls|Toccoa\s+Falls\s+College|Tougaloo|Tougaloo\s+College|Touro|Touro\s+College|Towson|Towson\s+University|Transylvania|Transylvania\s+University|Trevecca\s+Nazarene|Trevecca\s+Nazarene\s+University|Tri-State|Tri-State\s+University|Trinity|Trinity\s+Christian|Trinity\s+Christian\s+College|Trinity\s+College|Trinity\s+University|Troy\s+State\s+University--Dothan|Troy\s+State\s+University--Montgomery|Troy\s+State\s+University--Troy|Troy\s+State\s+University\s*[-:,]+\s*Dothan|Troy\s+State\s+University\s*[-:,]+\s*Montgomery|Troy\s+State\s+University\s*[-:,]+\s*Troy|Truman\s+State|Truman\s+State\s+University|Tufts|Tufts\s+University|Tulane|Tulane\s+University|Tusculum|Tusculum\s+College|Tuskegee|Tuskegee\s+University|UCB|UCLA|UCSD|UC\s+Berkeley|UC\s+Davis|UC\s+Irvine|UC\s+Riverside|UC\s+San\s+Diego|UC\s+Santa\s+Barbara|UC\s+Santa\s+Cruz|UPennn|UT\s+Arlington|UT\s+Austin|UT\s+Brownsville|UT\s+Dallas|UT\s+El\s+Paso|UT\s+Pan\s+American|UT\s+San\s+Antonio|UT\s+Tyler|UVA|Union|Union\s+College|Union\s+Institute|Union\s+University|United\s+States\s+Air\s+Force\s+Academy|United\s+States\s+Coast\s+Guard\s+Academy|United\s+States\s+Merchant\s+Marine\s+Academy|United\s+States\s+Military\s+Academy|United\s+States\s+Naval\s+Academy|Unity|Unity\s+College|University\s+of\s+Akron|University\s+of\s+Alabama|University\s+of\s+Alabama--Birmingham|University\s+of\s+Alabama--Huntsville|University\s+of\s+Alabama\s*[-:,]+\s*Birmingham|University\s+of\s+Alabama\s*[-:,]+\s*Huntsville|University\s+of\s+Alaska--Anchorage|University\s+of\s+Alaska--Fairbanks|University\s+of\s+Alaska--Southeast|University\s+of\s+Alaska\s*[-:,]+\s*Anchorage|University\s+of\s+Alaska\s*[-:,]+\s*Fairbanks|University\s+of\s+Alaska\s*[-:,]+\s*Southeast|University\s+of\s+Arizona|University\s+of\s+Arkansas|University\s+of\s+Arkansas--Little\s+Rock|University\s+of\s+Arkansas--Monticello|University\s+of\s+Arkansas--Pine\s+Bluff|University\s+of\s+Arkansas\s*[-:,]+\s*Little\s+Rock|University\s+of\s+Arkansas\s*[-:,]+\s*Monticello|University\s+of\s+Arkansas\s*[-:,]+\s*Pine\s+Bluff|University\s+of\s+Bridgeport|University\s+of\s+California|University\s+of\s+California--Berkeley|University\s+of\s+California--Davis|University\s+of\s+California--Irvine|University\s+of\s+California--Los\s+Angeles|University\s+of\s+California--Riverside|University\s+of\s+California--San\s+Diego|University\s+of\s+California--Santa\s+Barbara|University\s+of\s+California--Santa\s+Cruz|University\s+of\s+California\s*[-:,]+\s*Berkeley|University\s+of\s+California\s*[-:,]+\s*Davis|University\s+of\s+California\s*[-:,]+\s*Irvine|University\s+of\s+California\s*[-:,]+\s*Los\s+Angeles|University\s+of\s+California\s*[-:,]+\s*Riverside|University\s+of\s+California\s*[-:,]+\s*San\s+Diego|University\s+of\s+California\s*[-:,]+\s*Santa\s+Barbara|University\s+of\s+California\s*[-:,]+\s*Santa\s+Cruz|University\s+of\s+Central\s+Arkansas|University\s+of\s+Central\s+Florida|University\s+of\s+Central\s+Oklahoma|University\s+of\s+Charleston|University\s+of\s+Chicago|University\s+of\s+Cincinnati|University\s+of\s+Colorado--Boulder|University\s+of\s+Colorado--Colorado\s+Springs|University\s+of\s+Colorado--Denver|University\s+of\s+Colorado\s*[-:,]+\s*Boulder|University\s+of\s+Colorado\s*[-:,]+\s*Colorado\s+Springs|University\s+of\s+Colorado\s*[-:,]+\s*Denver|University\s+of\s+Connecticut|University\s+of\s+Dallas|University\s+of\s+Dayton|University\s+of\s+Delaware|University\s+of\s+Denver|University\s+of\s+Detroit\s+Mercy|University\s+of\s+Dubuque|University\s+of\s+Evansville|University\s+of\s+Findlay|University\s+of\s+Florida|University\s+of\s+Georgia|University\s+of\s+Great\s+Falls|University\s+of\s+Hartford|University\s+of\s+Hawaii--Hilo|University\s+of\s+Hawaii--Manoa|University\s+of\s+Hawaii\s*[-:,]+\s*Hilo|University\s+of\s+Hawaii\s*[-:,]+\s*Manoa|University\s+of\s+Houston|University\s+of\s+Houston--Downtown|University\s+of\s+Houston\s*[-:,]+\s*Downtown|University\s+of\s+Idaho|University\s+of\s+Illinois--Chicago|University\s+of\s+Illinois--Springfield|University\s+of\s+Illinois--Urbana-Champaign|University\s+of\s+Illinois\s*[-:,]+\s*Chicago|University\s+of\s+Illinois\s*[-:,]+\s*Springfield|University\s+of\s+Illinois\s*[-:,]+\s*Urbana-Champaign|University\s+of\s+Indianapolis|University\s+of\s+Iowa|University\s+of\s+Judaism|University\s+of\s+Kansas|University\s+of\s+Kentucky|University\s+of\s+La\s+Verne|University\s+of\s+Louisiana--Lafayette|University\s+of\s+Louisiana--Monroe|University\s+of\s+Louisiana\s*[-:,]+\s*Lafayette|University\s+of\s+Louisiana\s*[-:,]+\s*Monroe|University\s+of\s+Louisville|University\s+of\s+Maine--Augusta|University\s+of\s+Maine--Farmington|University\s+of\s+Maine--Fort\s+Kent|University\s+of\s+Maine--Machias|University\s+of\s+Maine--Orono|University\s+of\s+Maine--Presque\s+Isle|University\s+of\s+Maine\s*[-:,]+\s*Augusta|University\s+of\s+Maine\s*[-:,]+\s*Farmington|University\s+of\s+Maine\s*[-:,]+\s*Fort\s+Kent|University\s+of\s+Maine\s*[-:,]+\s*Machias|University\s+of\s+Maine\s*[-:,]+\s*Orono|University\s+of\s+Maine\s*[-:,]+\s*Presque\s+Isle|University\s+of\s+Mary|University\s+of\s+Mary\s+Hardin-Baylor|University\s+of\s+Maryland--Baltimore\s+County|University\s+of\s+Maryland--College\s+Park|University\s+of\s+Maryland--Eastern\s+Shore|University\s+of\s+Maryland--University\s+College|University\s+of\s+Maryland\s*[-:,]+\s*Baltimore\s+County|University\s+of\s+Maryland\s*[-:,]+\s*College\s+Park|University\s+of\s+Maryland\s*[-:,]+\s*Eastern\s+Shore|University\s+of\s+Maryland\s*[-:,]+\s*University\s+College|University\s+of\s+Massachusetts--Amherst|University\s+of\s+Massachusetts--Boston|University\s+of\s+Massachusetts--Dartmouth|University\s+of\s+Massachusetts--Lowell|University\s+of\s+Massachusetts\s*[-:,]+\s*Amherst|University\s+of\s+Massachusetts\s*[-:,]+\s*Boston|University\s+of\s+Massachusetts\s*[-:,]+\s*Dartmouth|University\s+of\s+Massachusetts\s*[-:,]+\s*Lowell|University\s+of\s+Memphis|University\s+of\s+Miami|University\s+of\s+Michigan|University\s+of\s+Michigan--Ann\s+Arbor|University\s+of\s+Michigan--Dearborn|University\s+of\s+Michigan--Flint|University\s+of\s+Michigan\s*[-:,]+\s*Ann\s+Arbor|University\s+of\s+Michigan\s*[-:,]+\s*Dearborn|University\s+of\s+Michigan\s*[-:,]+\s*Flint|University\s+of\s+Minnesota--Crookston|University\s+of\s+Minnesota--Duluth|University\s+of\s+Minnesota--Morris|University\s+of\s+Minnesota--Twin\s+Cities|University\s+of\s+Minnesota\s*[-:,]+\s*Crookston|University\s+of\s+Minnesota\s*[-:,]+\s*Duluth|University\s+of\s+Minnesota\s*[-:,]+\s*Morris|University\s+of\s+Minnesota\s*[-:,]+\s*Twin\s+Cities|University\s+of\s+Mississippi|University\s+of\s+Missouri--Columbia|University\s+of\s+Missouri--Kansas\s+City|University\s+of\s+Missouri--Rolla|University\s+of\s+Missouri--St\.?\s+Louis|University\s+of\s+Missouri\s*[-:,]+\s*Columbia|University\s+of\s+Missouri\s*[-:,]+\s*Kansas\s+City|University\s+of\s+Missouri\s*[-:,]+\s*Rolla|University\s+of\s+Missouri\s*[-:,]+\s*St\.?\s+Louis|University\s+of\s+Mobile|University\s+of\s+Montana|University\s+of\s+Montana--Western|University\s+of\s+Montana\s*[-:,]+\s*Western|University\s+of\s+Montevallo|University\s+of\s+Nebraska--Kearney|University\s+of\s+Nebraska--Lincoln|University\s+of\s+Nebraska--Omaha|University\s+of\s+Nebraska\s*[-:,]+\s*Kearney|University\s+of\s+Nebraska\s*[-:,]+\s*Lincoln|University\s+of\s+Nebraska\s*[-:,]+\s*Omaha|University\s+of\s+Nevada--Las\s+Vegas|University\s+of\s+Nevada--Reno|University\s+of\s+Nevada\s*[-:,]+\s*Las\s+Vegas|University\s+of\s+Nevada\s*[-:,]+\s*Reno|University\s+of\s+New\s+England|University\s+of\s+New\s+Hampshire|University\s+of\s+New\s+Haven|University\s+of\s+New\s+Mexico|University\s+of\s+New\s+Orleans|University\s+of\s+North\s+Alabama|University\s+of\s+North\s+Carolina--Asheville|University\s+of\s+North\s+Carolina--Chapel\s+Hill|University\s+of\s+North\s+Carolina--Charlotte|University\s+of\s+North\s+Carolina--Greensboro|University\s+of\s+North\s+Carolina--Pembroke|University\s+of\s+North\s+Carolina--Wilmington|University\s+of\s+North\s+Carolina\s*[-:,]+\s*Asheville|University\s+of\s+North\s+Carolina\s*[-:,]+\s*Chapel\s+Hill|University\s+of\s+North\s+Carolina\s*[-:,]+\s*Charlotte|University\s+of\s+North\s+Carolina\s*[-:,]+\s*Greensboro|University\s+of\s+North\s+Carolina\s*[-:,]+\s*Pembroke|University\s+of\s+North\s+Carolina\s*[-:,]+\s*Wilmington|University\s+of\s+North\s+Dakota|University\s+of\s+North\s+Florida|University\s+of\s+North\s+Texas|University\s+of\s+Northern\s+Colorado|University\s+of\s+Northern\s+Iowa|University\s+of\s+Notre\s+Dame|University\s+of\s+Oklahoma|University\s+of\s+Oregon|University\s+of\s+Pennsylvania|University\s+of\s+Pittsburgh|University\s+of\s+Pittsburgh--Bradford|University\s+of\s+Pittsburgh--Greensburg|University\s+of\s+Pittsburgh--Johnstown|University\s+of\s+Pittsburgh\s*[-:,]+\s*Bradford|University\s+of\s+Pittsburgh\s*[-:,]+\s*Greensburg|University\s+of\s+Pittsburgh\s*[-:,]+\s*Johnstown|University\s+of\s+Portland|University\s+of\s+Puget\s+Sound|University\s+of\s+Redlands|University\s+of\s+Rhode\s+Island|University\s+of\s+Richmond|University\s+of\s+Rio\s+Grande|University\s+of\s+Rochester|University\s+of\s+San\s+Diego|University\s+of\s+San\s+Francisco|University\s+of\s+Science\s+and\s+Arts\s+of\s+Oklahoma|University\s+of\s+Scranton|University\s+of\s+Sioux\s+Falls|University\s+of\s+South\s+Alabama|University\s+of\s+South\s+Carolina--Aiken|University\s+of\s+South\s+Carolina--Columbia|University\s+of\s+South\s+Carolina--Spartanburg|University\s+of\s+South\s+Carolina\s*[-:,]+\s*Aiken|University\s+of\s+South\s+Carolina\s*[-:,]+\s*Columbia|University\s+of\s+South\s+Carolina\s*[-:,]+\s*Spartanburg|University\s+of\s+South\s+Dakota|University\s+of\s+South\s+Florida|University\s+of\s+Southern\s+California|University\s+of\s+Southern\s+Colorado|University\s+of\s+Southern\s+Indiana|University\s+of\s+Southern\s+Maine|University\s+of\s+Southern\s+Mississippi|University\s+of\s+St\.?\s+Francis|University\s+of\s+St\.?\s+Thomas|University\s+of\s+Tampa|University\s+of\s+Tennessee--Chattanooga|University\s+of\s+Tennessee--Knoxville|University\s+of\s+Tennessee--Martin|University\s+of\s+Tennessee\s*[-:,]+\s*Chattanooga|University\s+of\s+Tennessee\s*[-:,]+\s*Knoxville|University\s+of\s+Tennessee\s*[-:,]+\s*Martin|University\s+of\s+Texas--Arlington|University\s+of\s+Texas--Austin|University\s+of\s+Texas--Brownsville|University\s+of\s+Texas--Dallas|University\s+of\s+Texas--El\s+Paso|University\s+of\s+Texas--Pan\s+American|University\s+of\s+Texas--San\s+Antonio|University\s+of\s+Texas--Tyler|University\s+of\s+Texas\s*[-:,]+\s*Arlington|University\s+of\s+Texas\s*[-:,]+\s*Austin|University\s+of\s+Texas\s*[-:,]+\s*Brownsville|University\s+of\s+Texas\s*[-:,]+\s*Dallas|University\s+of\s+Texas\s*[-:,]+\s*El\s+Paso|University\s+of\s+Texas\s*[-:,]+\s*Pan\s+American|University\s+of\s+Texas\s*[-:,]+\s*San\s+Antonio|University\s+of\s+Texas\s*[-:,]+\s*Tyler|University\s+of\s+Texas\s+of\s+the\s+Permian\s+Basin|University\s+of\s+Toledo|University\s+of\s+Tulsa|University\s+of\s+Utah|University\s+of\s+Vermont|University\s+of\s+Virginia|University\s+of\s+Virginia--Wise|University\s+of\s+Virginia\s*[-:,]+\s*Wise|University\s+of\s+Washington|University\s+of\s+West\s+Alabama|University\s+of\s+West\s+Florida|University\s+of\s+Wisconsin--Eau\s+Claire|University\s+of\s+Wisconsin--Green\s+Bay|University\s+of\s+Wisconsin--La\s+Crosse|University\s+of\s+Wisconsin--Madison|University\s+of\s+Wisconsin--Milwaukee|University\s+of\s+Wisconsin--Oshkosh|University\s+of\s+Wisconsin--Parkside|University\s+of\s+Wisconsin--Platteville|University\s+of\s+Wisconsin--River\s+Falls|University\s+of\s+Wisconsin--Stevens\s+Point|University\s+of\s+Wisconsin--Stout|University\s+of\s+Wisconsin--Superior|University\s+of\s+Wisconsin--Whitewater|University\s+of\s+Wisconsin\s*[-:,]+\s*Eau\s+Claire|University\s+of\s+Wisconsin\s*[-:,]+\s*Green\s+Bay|University\s+of\s+Wisconsin\s*[-:,]+\s*La\s+Crosse|University\s+of\s+Wisconsin\s*[-:,]+\s*Madison|University\s+of\s+Wisconsin\s*[-:,]+\s*Milwaukee|University\s+of\s+Wisconsin\s*[-:,]+\s*Oshkosh|University\s+of\s+Wisconsin\s*[-:,]+\s*Parkside|University\s+of\s+Wisconsin\s*[-:,]+\s*Platteville|University\s+of\s+Wisconsin\s*[-:,]+\s*River\s+Falls|University\s+of\s+Wisconsin\s*[-:,]+\s*Stevens\s+Point|University\s+of\s+Wisconsin\s*[-:,]+\s*Stout|University\s+of\s+Wisconsin\s*[-:,]+\s*Superior|University\s+of\s+Wisconsin\s*[-:,]+\s*Whitewater|University\s+of\s+Wyoming|University\s+of\s+the\s+Arts|University\s+of\s+the\s+District\s+of\s+Columbia|University\s+of\s+the\s+Incarnate\s+Word|University\s+of\s+the\s+Ozarks|University\s+of\s+the\s+Pacific|University\s+of\s+the\s+South|Upper\s+Iowa|Upper\s+Iowa\s+University|Urbana|Urbana\s+University|Ursinus|Ursinus\s+College|Ursuline|Ursuline\s+College|Utah\s+State|Utah\s+State\s+University|Utah\s+Valley\s+State|Utah\s+Valley\s+State\s+College|Utica|Utica\s+College|Valdosta\s+State|Valdosta\s+State\s+University|Valley\s+City\s+State|Valley\s+City\s+State\s+University|Valparaiso|Valparaiso\s+University|VanderCook|VanderCook\s+College\s+of\s+Music|Vanderbilt|Vanderbilt\s+University|Vanguard|Vanguard\s+University\s+of\s+Southern\s+California|Vassar|Vassar\s+College|Vermont\s+Technical|Vermont\s+Technical\s+College|Villa\s+Julie|Villa\s+Julie\s+College|Villanova|Villanova\s+University|Virginia\s+Commonwealth|Virginia\s+Commonwealth\s+University|Virginia\s+Intermont|Virginia\s+Intermont\s+College|Virginia\s+Military\s+Institute|Virginia\s+State|Virginia\s+State\s+University|Virginia\s+Tech|Virginia\s+Union|Virginia\s+Union\s+University|Virginia\s+Wesleyan|Virginia\s+Wesleyan\s+College|Viterbo|Viterbo\s+University|Voorhees|Voorhees\s+College|Wabash|Wabash\s+College|Wagner|Wagner\s+College|Wake\s+Forest|Wake\s+Forest\s+University|Waldorf|Waldorf\s+College|Walla\s+Walla|Walla\s+Walla\s+College|Walsh|Walsh\s+College\s+of\s+Accountancy\s+and\s+Business\s+Adm\.?|Walsh\s+University|Warner\s+Pacific|Warner\s+Pacific\s+College|Warner\s+Southern|Warner\s+Southern\s+College|Warren\s+Wilson|Warren\s+Wilson\s+College|Wartburg|Wartburg\s+College|Washburn|Washburn\s+University|Washington|Washington\s+College|Washington\s+State|Washington\s+State\s+University|Washington\s+University\s+in\s+St\.?\s+Louis|Washington\s+and\s+Jefferson|Washington\s+and\s+Jefferson\s+College|Washington\s+and\s+Lee|Washington\s+and\s+Lee\s+University|Wayland\s+Baptist|Wayland\s+Baptist\s+University|Wayne\s+State|Wayne\s+State\s+College|Wayne\s+State\s+University|Waynesburg|Waynesburg\s+College|Webb\s+Institute|Webber\s+International|Webber\s+International\s+University|Weber\s+State|Weber\s+State\s+University|Webster|Webster\s+University|Wellesley|Wellesley\s+College|Wells|Wells\s+College|Wentworth\s+Institute\s+of\s+Technology|Wesley|Wesley\s+College|Wesleyan|Wesleyan\s+College|Wesleyan\s+University|West\s+Chester|West\s+Chester\s+University\s+of\s+Pennsylvania|West\s+Liberty\s+State|West\s+Liberty\s+State\s+College|West\s+Texas\s+A&M|West\s+Texas\s+A&M\s+University|West\s+Virginia|West\s+Virginia\s+State|West\s+Virginia\s+State\s+College|West\s+Virginia\s+University|West\s+Virginia\s+University--Parkersburg|West\s+Virginia\s+University\s*[-:,]+\s*Parkersburg|West\s+Virginia\s+University\s+Institute\s+of\s+Technology|West\s+Virginia\s+Wesleyan|West\s+Virginia\s+Wesleyan\s+College|Western\s+Baptist|Western\s+Baptist\s+College|Western\s+Carolina|Western\s+Carolina\s+University|Western\s+Connecticut\s+State|Western\s+Connecticut\s+State\s+University|Western\s+Illinois|Western\s+Illinois\s+University|Western\s+International|Western\s+International\s+University|Western\s+Kentucky|Western\s+Kentucky\s+University|Western\s+Michigan|Western\s+Michigan\s+University|Western\s+New\s+England|Western\s+New\s+England\s+College|Western\s+New\s+Mexico|Western\s+New\s+Mexico\s+University|Western\s+Oregon|Western\s+Oregon\s+University|Western\s+State|Western\s+State\s+College\s+of\s+Colorado|Western\s+Washington|Western\s+Washington\s+University|Westfield\s+State|Westfield\s+State\s+College|Westminster|Westminster\s+College|Westmont|Westmont\s+College|Wheaton|Wheaton\s+College|Wheeling\s+Jesuit|Wheeling\s+Jesuit\s+University|Wheelock|Wheelock\s+College|Whitman|Whitman\s+College|Whittier|Whittier\s+College|Whitworth|Whitworth\s+College|Wichita\s+State|Wichita\s+State\s+University|Widener|Widener\s+University|Wilberforce|Wilberforce\s+University|Wiley|Wiley\s+College|Wilkes|Wilkes\s+University|Willamette|Willamette\s+University|William\s+Carey|William\s+Carey\s+College|William\s+Jewell|William\s+Jewell\s+College|William\s+Paterson|William\s+Paterson\s+University\s+of\s+New\s+Jersey|William\s+Penn|William\s+Penn\s+University|William\s+Tyndale|William\s+Tyndale\s+College|William\s+Woods|William\s+Woods\s+University|Williams|Williams\s+Baptist|Williams\s+Baptist\s+College|Williams\s+College|Wilmington|Wilmington\s+College|Wilson|Wilson\s+College|Wingate|Wingate\s+University|Winona\s+State|Winona\s+State\s+University|Winston-Salem\s+State|Winston-Salem\s+State\s+University|Winthrop|Winthrop\s+University|Wisconsin\s+Lutheran|Wisconsin\s+Lutheran\s+College|Wittenberg|Wittenberg\s+University|Wofford|Wofford\s+College|Woodbury|Woodbury\s+University|Worcester\s+Polytechnic\s+Institute|Worcester\s+State|Worcester\s+State\s+College|Wright\s+State|Wright\s+State\s+University|Xavier|Xavier\s+University|Xavier\s+University\s+of\s+Louisiana|Yale|Yale\s+University|Yeshiva|Yeshiva\s+University|York|York\s+College|York\s+College\s+of\s+Pennsylvania|Youngstown\s+State|Youngstown\s+State\s+University)}o;
#>

1;
