#!/usr/bin/perl -w
#< Boilerplate
#
# The Aranea question answering system
# Copyright (C) 2002-2005, Jimmy Lin
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, please visit
# http://www.gnu.org/copyleft/gpl.html
#
# $Header: /fs/clip-qa/.cvsroot//Aranea/pm/Aranea/Resources/Biography.pm,v 1.9 2005/06/09 11:46:51 jimmylin Exp $
#
#>
#< Header
package Aranea::Resources::Biography;

use strict;
use warnings;

use Aranea::Common qw(:default);

#>

#< STDIN handler
unless ( caller() ) {
    while ( <STDIN> ) {
	chop;
	my @args = split("\t", $_);
	my @results = get(@args);
	map { print "$_\n"; } @results;
    }
}
#>

#< sub get
sub get {
    my $entity = shift;
    my $property = shift;

    # empty hash to hold the results
    my $record = {};

    # ready entity for CGI querying
    $entity =~ s/'s$//;   # '; kill possessives
    $entity =~ s/ /+/g;

    # get the initial search result
    my $search_results = safe_get("http://search.biography.com/bio_ft_search.pl?word=$entity");

    # pick the first entry off the search results page: we assume that
    # it's the person we want.  Of course, in the case of ambiguous
    # names, it often may not be...
    return ()
	unless $search_results =~ /<A HREF="(print_record.pl\?id=\d+)">/s;
    my $r = $1;
    my $bio = safe_get("http://search.biography.com/$r ");

    #$bio = HTML::Entities::encode_entities($bio);
    #print "$bio\n";

    # get the lifespan, e.g., ( 1923 -- 2002 )
    # watch for tricky ones, e.g., Pythogras (c. 550BC -- )
    $bio =~ /COLOR="#252525"><B>((c.\s+)?(\d+[^<]+))/;
    my $lifespan = $1;
    $record->{lifespan} = $lifespan;

    # get the raw birth and death years
    my ($rawb, $rawd) = split('--', $lifespan, 2);
    my $byear = '';
    my $dyear = '';

    $byear = $& if $rawb =~ /\d+\s*(BC)?/;
    $dyear = $& if $rawd =~ /\d+\s*(BC)?/;

    $byear =~ s/ +$//g;
    $byear =~ s/^ +//g;
    $dyear =~ s/ +$//g;
    $dyear =~ s/^ +//g;

    my ($birthdate, $deathdate) = ($byear, $dyear);

    # if available, look for actual month and date.  The regexp is
    # overly general because some entries have strange birthdates,
    # e.g.,
    #   Beethoven => "December 16 (some sources say December 17), 1770"

    my $months = "(Jan|Feb|March|April|May|Jun|Jul|Aug|Sept|Oct|Nov|Dec)";
    $birthdate = $1 if ( $bio =~ /[Bb]orn.{0,50}($months.{0,50}$byear)/s );
    $deathdate = $& if ( $bio =~ /$months.{0,20}$dyear/s );

    # kill the extra paren in the Beethoven case above
    $birthdate =~ s/[()]//g;

    $record->{birthdate} = $birthdate;
    $record->{deathdate} = $deathdate;

    # the birthplace, usually in a locative PP.
    my $birthplace = '';

    # kill all parenthetical expressions, they get in the way of the
    # actual extraction, e.g., John Adams.

    $bio =~ s/\([^)]+\)//g;
    $bio =~ s/\s,/,/g;

    # make sure we can find the locative PP, because it may be missing
    # from some biographies.
    if ( $bio =~ /[Bb]orn .*?in (([A-Z][^ ]+ )+)/ ) {
	$birthplace = $1;
	$birthplace =~ s/\. .*$//g;
	$birthplace =~ s/ +$//;
	$record->{birthplace} = $birthplace;
    }

    # find the property we want
    my @results = ();
    if ( $property and exists $record->{$property} ) {
	push @results, $record->{$property};
    }

    # basically, for debugging purposes only
    unless ( $property ) {
	print "lifespan: $record->{lifespan}\n";
	print "birthdate: $record->{birthdate}\n";
	print "birthplace: $record->{birthplace}\n";
	print "deathdate: $record->{deathdate}\n";
    }

    return @results;
}
#>

1;
